function planarSpiralInductor2

        setFigure('Planar Spiral Inductor');
   FS = 16;
    p = defParams;
        plotTopView( p, FS)
        plotSideView(p, FS)
        
         

return

function p = defParams

    p.N = 5;
    p.a = 1;
    p.b = sqrt(2)*p.a;
    p.t = .12;
    p.g = .12;
    p.w = .05;
    p.d = .02;
    p.D = 2*p.w;                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     

return

function plotTopView( p, FS)

    axes('position',[.55 .3 .4 .4])
    axis off
    axis equal
    hold on;
    plotSubstrate(p, FS)
    plotTurns( p, FS )
    set(gca,'fontsize',FS)
    title('Top View -- middle plane')
    
return

    function plotSubstrate(p,FS)

    patch([-1 1 1 -1]*p.b/2,[-1 -1 1 1]*p.b/2,[1 1 1]*.95);
    hold on;
    arrowsWithLabel(.5*p.b,.8*p.b, p.b/2, FS, ' b')
    arrowsWithLabel(.5*p.a,.65*p.b, p.a/2, FS, ' a')
    plot([-1 1]*.55*p.b,[0 0],'k');
    plot([-1 -1]*.55*p.b,[0,.1*p.b],'k');
    plot(-.55*p.b,.1*p.b,'k^')
    plot([1 1]*.55*p.b,[0,.1*p.b],'k');
    plot(.55*p.b,.1*p.b,'k^')
        
return

    function arrowsWithLabel(xR, xOut, yHeight, FS, lab)

    plot([xR, xOut+.1], [1 1]*yHeight,'k-');
    plot([xR, xOut+.1], -[1 1]*yHeight,'k-');
    arrow([xOut,-yHeight],[xOut,yHeight])
    arrow([xOut,yHeight],[xOut,-yHeight])
    text(xOut,0,['\it' lab],'fontsize',FS)

return

    function plotTurns( p, FS )

    patch([-1 1 1 -1]*p.w/2, [-p.D -p.D -p.b/2 -p.b/2],...
          [1 1 1]*.95,'linestyle',':');
    for i = 1:p.N
        Xo = p.a/2 - (i-1)*p.D + p.w/2;
        patch([-Xo, -Xo, Xo, Xo, -Xo+p.D,...
               -Xo+p.D, Xo-p.w, Xo-p.w,-Xo+p.w,-Xo+p.w],...
              [-Xo-p.D, Xo, Xo, -Xo, -Xo,...
               -Xo+p.w, -Xo+p.w Xo-p.w Xo-p.w -Xo-p.D],...
               [1 1 1]*.2,'edgecolor',[1 1 1]*.2);
    end;
    
    arrow([-1.3*p.a/2, -p.a/2-p.D/2],[-p.a/2-p.w/2,-p.a/2-p.D/2])
    arrow([-.7*p.a/2, -p.a/2-p.D/2],[-p.a/2+p.w/2,-p.a/2-p.D/2])
    text(-1.3*p.a/2,-p.a/2,'\itw','fontsize',FS,...
        'verticalalignment','bottom')
    
return

function plotSideView(p, FS)

        axes('position',[.05 .3 .4 .4]);
        axis off; hold on; axis equal
        plotLayers( p, FS )
        labelLayers( p, FS)
        plotWires( p, FS)
        labelRect(p, FS)
        set(gca,'fontsize',FS)
        title('Side View')

return

    function plotLayers( p, FS )

        patch([-1 1 1 -1]*p.b/2,...
              [0 0 1 1]*p.t+p.g/2,...
              [1 1 1]*.6);
        patch([-1 1 1 -1]*p.b/2,...
              -[0 0 1 1]*p.t-p.g/2,...
              [1 1 1]*.6);
        patch([-1 1 1 -1]*p.b/2,...
              [-1 -1 1 1]*p.g/2,...
              [1 1 1]);
        plot([-1 1]*p.b/2,[0 0],'k--');

return

    function labelLayers( p, FS)

        plot(-[p.b/2,.6*p.b],[1 1]*p.g/2+p.t,'k');
        plot(-[p.b/2,.6*p.b],[1 1]*p.g/2,'k');
        plot(-[p.b/2,.6*p.b],-[1 1]*p.g/2,'k');
        plot(-[p.b/2,.6*p.b],-[1 1]*p.g/2-p.t,'k');
        
        arrow([-.55*p.b, p.g/2],[-.55*p.b,p.g/2+p.t]);
        arrow([-.55*p.b,p.g/2+p.t],[-.55*p.b, p.g/2]);
        text(-.55*p.b,p.g/2+p.t/2,'  \itt  ','FontSize',FS,...
             'horizontalalignment','right');
        text(p.b/2,p.g/2+p.t/2,' \leftarrow mag. layer','fontsize',FS);

        arrow([-.55*p.b, p.g/2],[-.55*p.b,-p.g/2]);
        arrow([-.55*p.b,-p.g/2],[-.55*p.b, p.g/2]);
        text(-.55*p.b,0,'  \itg  ','FontSize',FS,...
             'horizontalalignment','right');
        text(p.b/2,0,' \leftarrow insul. layer','fontsize',FS);
        
        arrow([-.55*p.b, -p.g/2],[-.55*p.b,-p.g/2-p.t]);
        arrow([-.55*p.b,-p.g/2-p.t],[-.55*p.b, -p.g/2]);
        text(-.55*p.b,-p.g/2-p.t/2,'  \itt  ','FontSize',FS,...
            'horizontalalignment','right');
        text(p.b/2,-p.g/2-p.t/2,' \leftarrow mag. layer','fontsize',FS);


return

    function plotWires( p, FS)

    plot([-1 1 1 -1 -1]*p.w/2,[0 0 -1 -1 0]*(p.g/2+p.t),'k:');

    for i = 1:p.N
       patch(-p.a/2+(i-1)*p.D+[1 -1 -1 1]*p.w/2,...
             [-1 -1 1 1]*p.d/2,...
             [1 1 1]*1,'edgecolor',[1 1 1]*.2);
       plot(-p.a/2+(i-1)*p.D+[1 -1]*p.w/2,[-1 1]*p.d/2,'k');
       plot(-p.a/2+(i-1)*p.D+[1 -1]*p.w/2,[1 -1]*p.d/2,'k');
       
       
       patch(p.a/2-(i-1)*p.D+[1 -1 -1 1]*p.w/2,...
             [-1 -1 1 1]*p.d/2,...
             [1 1 1]*1,'edgecolor',[1 1 1]*.2);
       plot(p.a/2-(i-1)*p.D,0,'.k');
    end
    patch([-1 1 1 -1]*p.w/2,...
             [-1 -1 1 1]*p.d/2-p.g/2-p.t-p.d/2,...
             [1 1 1]*1,'edgecolor',[1 1 1]*.2);
    plot(0,p.d/2-p.g/2-p.t-p.d,'k.');
         
         
return

    function labelRect(p, FS)
       
        plot([1 1]*p.b/2,p.g/2+p.t+[0 .1*p.b],'k');
        plot(-[1 1]*p.b/2,p.g/2+p.t+[0 .1*p.b],'k');
        arrow([-p.b/2,p.g/2+p.t+.05*p.b],[p.b/2,p.g/2+p.t+.05*p.b])
        arrow([p.b/2,p.g/2+p.t+.05*p.b],[-p.b/2,p.g/2+p.t+.05*p.b])
        text(0,p.g/2+p.t+.05*p.b,'\itb','fontsize',FS,...
            'horizontalalignment','center','verticalalignment','bottom');
        
        plot([1 1]*p.a/2,-([0 p.g/2+p.t+.1*p.b]),'k');
        plot(-[1 1]*p.a/2,-([0 p.g/2+p.t+.1*p.b]),'k');
        arrow([-p.a/2,-(p.g/2+p.t+.05*p.b)],[p.a/2,-(p.g/2+p.t+.05*p.b)])
        arrow([p.a/2,-(p.g/2+p.t+.05*p.b)],[-p.a/2,-(p.g/2+p.t+.05*p.b)])
        text(0,-(p.g/2+p.t+.05*p.b),'\ita','fontsize',FS,...
            'horizontalalignment','center','verticalalignment','top');        
    return
            

