function duffingHist2

                       setFigure
    [Xn, w1, w2, ...
         ind1, ind2,...
         phi1, phi2] = duffingFreqResp;
    [indDown, indUp,...
             indUp2] = plotAmplitudeResponse(Xn, w1, w2, ind1, ind2);
                       plotPhaseResponse(w1,w2,phi1,phi2,indDown,indUp, indUp2)
    
    
return

function setFigure

    fName = 'Freq response of Duffing Eq';
    fH = findobj('name',fName);
    if isempty(fH)
        figure('name',fName,'numbertitle','off');
    else
        figure(fH);clf
    end;
    

return

function [Xn, w1, w2, ...
             ind1, ind2,...
             phi1, phi2] = duffingFreqResp

    % define resonator parameters
    k = 1;
    F = 1;
    a = 0.01;
    Q = 12;
    Xn = 0:.01:1.5*Q;
    % compute coefficients of the biquadratic equation
    b = 1/Q^2-2-3/2*a.*(F/k)^2*Xn.^2;
    c = 1-1./Xn.^2 + 3/2*a*(F/k)^2*Xn.^2 + 9/16*a.^2*(F/k)^4*Xn.^4;
    % compute frequency
    w1 = sqrt(-b/2+sqrt( (b/2).^2 - c));  % red trace
    w2 = sqrt(-b/2-sqrt( (b/2).^2 - c));  % blue trace  
    % ignore the complex data and data outside of the range of interest
    ind1 = find( w1 == real(w1) & w1 < 3);
      w1 = w1(ind1);
    ind2 = find(w2 == real(w2));
      w2 = w2(ind2);
    % compute angle 
    phi1 = -atan2( w1/Q,(1-w1.^2+3/4*a*Xn(ind1).^2*(F/k)^2) )*180/pi;
    phi2 = -atan2( w2/Q,(1-w2.^2+3/4*a*Xn(ind2).^2*(F/k)^2))*180/pi;

return

function [indDown, indUp, indUp2] = plotAmplitudeResponse(Xn, w1, w2, ind1, ind2)

    axes('position',[.15 .55 .8 .4]);
    plot(w1,Xn(ind1),'r','linewidth',2); hold on;
    plot(w2,Xn(ind2),'b','linewidth',2)
    set(gca,'fontsize',14,'xticklabel',[]);
    ylabel({'Normalized';'Displacement  \itX_n'});
    % Amplitude w->
        addArrows(1, 1,'b', w2, Xn(ind2),'bottom',2,200)
        % snap down Amplitude
        indDown = find(w1 < w2(end),1);
        plot(w2(end)*[1 1],[Xn(ind2(end)), Xn(ind1(indDown))],':');
        plot(w2(end), mean([Xn(ind2(end)), Xn(ind1(indDown))]),'v','markerfacecolor','b')
        addArrows( -1,-1,'b',w1(1:indDown),Xn(ind1(1:indDown)),'bottom',2,50)
    % Amplitude w<-
        indUp = find(w1 == min(w1));
        indUp2 = find(w2>w1(indUp),1);
        addArrows( 1,1,'r',w1(1:indUp),Xn(ind1(1:indUp)),'bottom',20,100)
        % snap up Amplitude
        plot(w1(indUp)*[1 1],[Xn(ind1(indUp)), interp1(w2,Xn(ind2),w1(indUp))],'r:');
        plot(w1(indUp), .3*Xn(ind1(indUp))+ .7*interp1(w2,Xn(ind2),w1(indUp)),'r^','markerfacecolor','r')    % phase:
        addArrows(-1,-1,'r',w2(1:indUp2-1),Xn(ind2(1:indUp2-1)),'bottom',2,400)

return

function plotPhaseResponse(w1,w2,phi1,phi2,indDown,indUp, indUp2)

    axes('position',[.15 .15 .8 .4])
    plot(w1,phi1,'r','linewidth',2);hold on
    plot(w2,phi2,'b','linewidth',2);
    set(gca,'fontsize',14)
    addArrows(1, 1,'b',w2, phi2,'bottom',2,200 )
    plot(w2(end)*[1 1],[phi2(end), phi1(indDown)],'b:');
    plot(w2(end),mean([phi2(end), phi1(indDown)]),'bv','markerfacecolor','b');
    addArrows(-1,-1,'b',w1(1:indDown),phi1(1:indDown),'bottom',2,50);
    addArrows(1,1,'r',w1(1:indUp),phi1(1:indUp),'bottom',2,200);
    plot(w1(indUp)*[1 1],[phi1(indUp), interp1(w2,phi2,w1(indUp))],'r:');
    plot(w1(indUp),.5*phi1(indUp) + .5*interp1(w2,phi2,w1(indUp)),'^r','markerfacecolor','r')
    addArrows(-1,-1,'r',w2(1:indUp2-1),phi2(1:indUp2-1),'bottom',2,200)
    xlabel('Relative frequency \it\omega_r')
    ylabel('Angle \it\phi\rm [^o]')

return

function addArrows( xSign, ySign, col, x, y, vertAlig,s,inc )

    xL = diff(get(gca,'xlim'));
    yL = diff(get(gca,'ylim'));
    pA = get(gca,'position');
    pF = get(gcf,'position');
    
    for i = s:inc:length(x)
        dy = ySign*( y(i)-y(i-1) ) / yL * pA(4) * pF(4);
        dx = xSign*( x(i)-x(i-1) ) / xL * pA(3) * pF(3);
        phi = atan2(dy,dx)*180/pi;
        text(x(i),y(i),'\rightarrow','rotation',phi,'color',col,...
             'horizontalalignment','center','verticalalignment',vertAlig)
    end;

    
return


