function cubicSi_CUP(viewType)

    if nargin < 1
        viewType = 'singleCube';
    end;

    setFigure('Si cube')
    a = 1;
    r = .1;
    FS = 9;
    axes('position',[.01,.5,.4,.4])
    showViews('singleCube')
    view(-28.5,8);view(-21.5,24)
    annotation('textbox',[.4, .7, .05,.05], 'fontsize',9,...
    'string','(a)','linestyle','none')  
    
    axes('position',[.5,.5,.4,.4])
    showViews('intersectingCubes')
    annotation('textbox',[.88, .7, .05,.05], 'fontsize',9,...
    'string','(b)','linestyle','none')  
    
    axes('position',[.01,.01,.4,.4])
    showViews('justTetrahedron')
    annotation('textbox',[.4, .25, .05,.05], 'fontsize',9,...
    'string','(c)','linestyle','none')  
    
    
    axes('position',[.5,.01,.4,.4])
    showViews('connectedCube')
    view(-26.5,14)
    annotation('textbox',[.88, .25, .05,.05], 'fontsize',9,...
    'string','(d)','linestyle','none')  
    
    
    colormap('gray')
    set(gcf,'paperposition',[1 1 6 4],'renderer','opengl')
    print -dtiff -r1200 Fig_C7
    function showViews(viewType)
    switch viewType
        case 'singleCube'
               R = 0*[1 1 1];
                   baseCube(R,a,[1 1 1]*.5);
                   set(get(gca,'children'),'markersize',FS);
                   text(0,a/2,0,'\ita','fontsize',FS,'horizontalalignment','right','verticalalignment','top')
                   text(0,a,a/2,'\ita  ','fontsize',FS,'horizontalalignment','right')
                   text(a/2,a,a,'\ita','fontsize',FS,'horizontalalignment','right','verticalalignment','bottom')
                   plot3([0 a],[0 a],[0, a],'k','linewidth',1.5)
                   text(a/2,a/2,a/2,'      Main diagonal, 3^{1/2}\ita','Fontsize',FS-1,...
                        'horizontalalignment','center',...
                        'verticalalignment', 'top',...
                        'rotation',70)                   
        case 'intersectingCubes'
               R = 0*[1 1 1];
                   baseCube(R,a,[1 1 1]*.5);
               R = 3/4*a*[1 1 1];
                   baseCube(R,a,[1 1 1]*.95);
                   tetrahedrons( a, 0 )
                   view(-12.5,18)
                    h=findobj('marker','o','parent',gca);
                    set(h,'markersize',6)
                    
                   
        case 'justTetrahedron'
            tetrahedrons( a, 1 )
            view(-12.5,18)
        case 'connectedCube'
               R = 0*[1 1 1];
                   baseCube(R,a,[1 1 1]*.5);
                   hold on;
                   addAttomsFromNeighbors(a)
                   set(get(gca,'children'),'markersize',9);
    end;
    end

    
    
    
end

function baseCube(R,a,cubeColor)
    
    x = R(1) + a*[0 1 1 0;
                  0 1 1 0;
                  0 0 0 0;
                  1 1 1 1];
    y = R(2) + a*[0 0 1 1;
                  0 0 1 1;
                  0 1 1 0;
                  0 1 1 0];
    z = R(3) + a*[0 0 0 0;
                  1 1 1 1;
                  0 0 1 1;
                  0 0 1 1];
              
    % draw the cube with atoms at vertices
    for i = 1:4
        patch(x(i,:),y(i,:),z(i,:),[1 1 1],'facecolor','none',...
             'linestyle','--','linewidth',.5,...
             'marker','o','markersize',9,'markerfacecolor',cubeColor,'tag','base'); hold on;
    end;
    plot3([0,.5,.5,1,.5,.5]+R(1),[.5, 0,1,.5,.5,.5]+R(3),[.5,.5,.5,.5,0,1]+R(2),'ko',...
        'markersize',9,'markerfacecolor',cubeColor,'tag','face');  % draw atoms at the faces

    hold on;
    axis off
    axis equal
    view(3)
    xM = R(1) + a*[1 1; 1 1; 0 0; 0 0; 0 1; 0 1; 0 1; 0 1; 0 1; 1 0; 0 1; 1 0];
    yM = R(2) + a*[0 1; 1 0; 0 1; 1 0; 1 1; 1 1; 0 0; 0 0; 0 1; 0 1; 0 1; 0 1];
    zM = R(3) + a*[0 1; 0 1; 0 1; 0 1; 0 1; 1 0; 0 1; 1 0;1 1; 1 1; 0 0; 0 0;];
    for i = 1:size(xM,1)
        plot3(xM(i,:), yM(i,:), zM(i,:),':','color',[1 1 1]*.3,'linewidth',.5);
    end;
    

end

function tetrahedrons( a, addAtoms )

    x = a*[1, .75;1 1.25;1 1.25; 1 .75; .75 1; .75 .5;.75 .5];
    y = a*[1, 1.25;1 .75;1 1.25; 1 .75; .75 .5; .75 1;.75 .5];
    z = a*[1, 1.25;1 1.25;1 .75; 1 .75; .75 .5; .75 .5;.75 1];
    o = [1:4,1,3,2,4];
    hold on;
    if addAtoms
        L = 4; plot3(x(o,:),y(o,:),z(o,:),'k:'); 
    else
        L = 7;
    end;
    
    for i = 1:L
        plot3(x(i,:),y(i,:),z(i,:),'linewidth',1.5,'color','k');
        if addAtoms
            plot3(x(i,:),y(i,:),z(i,:),'ko','markerfacecolor',...
                  [1 1  1]*.95,'markersize',9);
            axis off;
        end
    end;
    if addAtoms
        plot3(a,a,a,'ko','markersize',9,'markerfacecolor',[1 1 1]*.5);
    end


end

function addAttomsFromNeighbors(a)

    x = [.25 .75 .75 .25];
    y = [.25 .75 .25 .75];
    z = [.25 .25 .75 .75 ];
    k = findobj('parent',gca,'tag','face')
    xF = get(k,'xdata');
    yF = get(k,'ydata');
    zF = get(k,'zdata');
    kB = findobj('parent',gca,'tag','base')
    for i = 1:length(kB)
        xF = [xF, get(kB(i),'xdata')'];
        yF = [yF, get(kB(i),'ydata')'];
        zF = [zF, get(kB(i),'zdata')'];
    end;
    X = [xF;yF;zF]';
    X = unique(X,'rows');
    
    for i = 1:length(x)
        d = sqrt( (x(i)-X(:,1)).^2 + (y(i)-X(:,2)).^2 + (z(i)-X(:,3)).^2);
        [d,ind] = sort(d);
       
        for j = 1:4
            plot3([X(ind(j),1) x(i)], [X(ind(j),2) y(i)], [X(ind(j),3) z(i)],...
                 'linewidth',2,'color',[1 1 1]*.3);
        end;
    end;
    plot3(x,y,z,'ko','markersize',9,'markerfacecolor',[1 1 1]*.95);    
             

end