function lith(FigNum)

    if nargin < 1
        FigNum = 'b';
        setFigure('Lith Process'); set(gcf,'position',[0.28 0.28    0.63    0.6]);
        set(gca,'position',[.25 0 .75 1],'zlim',[-.3 .6])
        FS = 16;FS = 9;
        AS = 10;
        hold on;
    else
        set(gca,'zlim',[-.1, 1])
        hold on;
        FS = 9;
        AS = 8;
    end;
    d.L = 1;  % sub length
    d.W = 1;  % sub width
    d.H = .2; % sub thick
    d.h = .1; % photoresist th
    d.D = .2; % mask distance
    d.M = .02;% mask h
    d.N = .1;
    d.w = .15;
    d.l = .2;
    d.T = .2;
    
%     setFigure('Lith Process'); set(gcf,'position',[0.28 0.28    0.63    0.6]);
    makeSubstrate(d,FS)
    %[.25 0 .75 1]
%         set(gca,'position',[.5 .5 .3 .3],'zlim',[-.3 .6])    
    
    switch FigNum
        case 'b'
            drawLight(d,FS,AS)
            makeMask(d,FS)
            makePhotoR(d, FS)
%             print -dpng FigC3b
        case 'd'
            makePhotoRnegative(d, FS)
%             print -dpng FigC3c
        case 'c'
            makePhotoRpositive(d, FS)
%             print -dpng FigC3c
    end
    

return

function makeSubstrate(d,FS)

    q = linspace(0,2*pi,40);
    % top + bottom
    patch([-1 1 1 -1]*d.L/2,[-1 -1 1 1]*d.W/2,[1 1 1 1]*d.H/2,[1 1 1]*.9)
    % front + back
    patch([linspace(-d.L/2,d.L/2,40),d.L/2,-d.L/2],...
          -ones(1,42)*d.W/2,[-d.H/2-d.H/5*sin(q), [1 1]*d.H/2],[1 1 1]*.82)
    % left + right
    patch(-ones(1,42)*d.L/2,[linspace(-d.W/2,d.W/2,40),d.W/2,-d.W/2],...
         [-d.H/2-d.H/5*sin(q), [1 1]*d.H/2],[1 1 1]*.9)
    view(-35.5,14)
    set(gca,'zlim',[-.3 .6])
    axis 'equal'
    axis off
    text(-d.L/2-.12,0,0,'Substrate ','FontSize',FS,'horizontalalignment','center',...
        'rotation',-16,'verticalalignment','bottom')
    
    
return

function makePhotoR(d, FS)

    % top
    patch([-1 1 1 -1]*d.L/2,[-1 -1 1 1]*d.W/2,[1 1 1 1]*(d.H/2+d.h),[1 1 1]*.85,...
        'edgecolor','none')
    patch([-1 1 1 -1]*d.l/2,[-1 -1 1 1]*d.w/2,[1 1 1 1]*(d.H/2+d.h),[1 1 1]*.85,...
        'linestyle',':')
    % front + back
    patch([-1 1 1 -1]*d.L/2,-ones(1,4)*d.W/2,[1 1 0 0]*d.h+d.H/2,[1 1 1]*.75)
    % left + right
    patch(-[1 1 1 1]*d.L/2,[1 -1 -1 1]*d.W/2,[1 1 0 0]*d.h+d.H/2,[1 1 1]*.85)
    %cover up the black line:
    plot3([d.W,d.H]/2*cos(pi/4),[d.W,d.H]/2*sin(pi/4),d.H/2*[1 1],'color',[1 1 1]*.85)
    text(0,-d.W/2-.12,d.H/2+d.h/2,'Photoresist',...
        'FontSize',FS,'horizontalalignment','center',...
        'verticalalignment','bottom',...
        'rotation',8)
return

function makePhotoRpositive(d, FS)

    % top
    patch([-1 1 1 -1]*d.l/2,[-1 -1 1 1]*d.w/2,[1 1 1 1]*(d.H/2+d.h),[1 1 1]*.85)
    % front + back
    patch([-1 1 1 -1]*d.l/2,-ones(1,4)*d.w/2,[1 1 0 0]*d.h+d.H/2,[1 1 1]*.75)
    % left + right
    patch(-[1 1 1 1]*d.l/2,[1 -1 -1 1]*d.w/2,[1 1 0 0]*d.h+d.H/2,[1 1 1]*.85)
    
    text(d.L/2,d.w/2,d.h/2,'\leftarrowPhotoresist',...
        'FontSize',FS,'horizontalalignment','center',...
        'verticalalignment','bottom',...
        'rotation',0)
return

function makePhotoRnegative(d, FS)

    patch([-d.L, d.L, d.L, d.l, d.l,-d.l,-d.l,d.l,d.L,-d.L]/2,...
          [-d.W,-d.W, d.W, d.w,-d.w,-d.w, d.w,d.w,d.W, d.W]/2,...
          ones(1,10)*(d.H/2+d.h),...
          [1 1 1]*.85)
      
    % front + back
    patch([-1 1 1 -1]*d.L/2,-ones(1,4)*d.W/2,[1 1 0 0]*d.h+d.H/2,[1 1 1]*.75)
    % left + right
    patch(-[1 1 1 1]*d.L/2,[1 -1 -1 1]*d.W/2,[1 1 0 0]*d.h+d.H/2,[1 1 1]*.85)
    patch([1 1 1 1]*d.L/2,[1 -1 -1 1]*d.W/2,[1 1 0 0]*d.h+d.H/2,[1 1 1]*.85)
    % window
    patch([-1 1 1 -1]*d.l/2,ones(1,4)*d.w/2,[1 1 0 0]*d.h+d.H/2,[1 1 1]*.75)
    patch([1 1 1 1]*d.l/2,[1 -1 -1 1]*d.w/2,[1 1 0 0]*d.h+d.H/2,[1 1 1]*.85);hold on;
    % cover-up line
    plot3([d.l/2,d.L/2],[d.w/2, d.W/2],[1 1]*(d.H/2+d.h)+1e-3,'color',[1 1 1]*.85,'linewidth',1)
        text(0,-d.W/2-.12,d.H/2+d.h/2,'Photoresist',...
        'FontSize',FS,'horizontalalignment','center',...
        'verticalalignment','bottom',...
        'rotation',8)

return

function makeMask(d,FS)

    patch([-d.L, d.L, d.L, d.l, d.l,-d.l,-d.l,d.l,d.L,-d.L]/2,...
          [-d.W,-d.W, d.W, d.w,-d.w,-d.w, d.w,d.w,d.W, d.W]/2,...
          ones(1,10)*(d.H/2+d.h+d.D+d.M),...
          [1 1 1]*.6,'edgecolor','none')
      
    % front + back
    patch([-1 1 1 -1]*d.L/2,-ones(1,4)*d.W/2,[1 1 0 0]*d.M+d.H/2+d.h+d.D,[1 1 1]*.5)
    % left + right
    patch(-[1 1 1 1]*d.L/2,[1 -1 -1 1]*d.W/2,[1 1 0 0]*d.M+d.H/2+d.h+d.D,[1 1 1]*.6)
    patch([1 1 1 1]*d.L/2,[1 -1 -1 1]*d.W/2,[1 1 0 0]*d.M+d.H/2+d.h+d.D,[1 1 1]*.6)
    % window
    patch([-1 1 1 -1]*d.l/2,ones(1,4)*d.w/2,[1 1 0 0]*d.M+d.H/2+d.h+d.D,[1 1 1]*.5)
    patch([1 1 1 1]*d.l/2,[1 -1 -1 1]*d.w/2,[1 1 0 0]*d.M+d.H/2+d.h+d.D,[1 1 1]*.6)
    
    % quartz
    patch([-1 1 1 -1]*d.L/2,[-1 -1 1 1]*d.W/2,[1 1 1 1]*(d.H/2+d.h+d.D+d.M+d.N),...
          [1 1 1]*.95,'facecolor','none')
    patch([-1 1 1 -1]*d.L/2,[1 1 1 1]*d.W/2,[1 1 0 0]*d.N+(d.H/2+d.h+d.D+d.M),...
          [1 1 1]*.95,'facecolor','none')
        patch([-1 1 1 -1]*d.L/2,-[1 1 1 1]*d.W/2,[1 1 0 0]*d.N+(d.H/2+d.h+d.D+d.M),...
          [1 1 1]*.95,'facecolor','none')

    text(-d.L/2,d.W/2,d.H/2+d.h+d.D+d.M+d.N,'Mask: quartz plate\rightarrow',...
         'fontsize',FS,'horizontalalignment','right');
    text(-d.L/2,d.W/2,d.H/2+d.h+d.D+d.M,'patterned chromium\rightarrow',...
         'fontsize',FS,'horizontalalignment','right');
return

function drawLight(d,FS,AS)
    N = 5;
    M = 5;
    zHigh = d.H/2 + d.h + d.D + d.M + d.N + d.T;
    for i = 1:N
        for j = 1:M
            x = -d.L/2+i*d.L/(N+1);
            y = -d.W/2+j*d.W/(M+1); 
            if (-d.l/2 < x && x < d.l/2 && -d.w/2 < y && y < d.w/2)
                zLow = d.H/2 + d.h;
            else
                zLow = d.H/2 + d.h + d.D + d.M;
            end;
            arrow([x,y,zHigh],[x,y,zLow],AS);
        end;
    end;

    text(0,d.W/2,d.H/2+d.h+d.D+d.M+d.T,'UV light',...
         'fontsize',FS,'horizontalalignment','right');

    
return