function spinPhotoresist(in)

   if nargin < 1
       setFigure('Spin Photoresist')
       set(gcf,'renderer','painters');
   end;
   FS = 9;
   LW = 1;
   AS = 8;
   waferHolder(FS)
   makeWafer(FS,LW)
   showSpin(FS,LW,AS)
   makeDispenser(FS,LW)
   makeAblob(LW)
   set(gcf,'renderer','painters')
   print -dbitmap FigC3a
   function makeWafer(FS,LW)
       q = linspace(-pi/2+pi/6,3*pi/2-pi/6,100);
       patch(cos(q),sin(q),ones(size(q))*.01,[1 1 1]*.5,...
             'linewidth',LW);
       axis equal
       axis off
       view(-1,42)
       axis(axis)
       hold on;
   end
   function waferHolder(FS)
       phi = linspace(0,2*pi,100)+pi/2;
       r = 1.1;
       h = -.2;
       H = -1;
%        patch([r/8*cos(phi),r/8*cos(fliplr(phi))],...
%              [r/8*sin(phi),r/8*sin(fliplr(phi))],...
%              [zeros(size(phi)),H*ones(size(phi))],...
%              [1 1 1]*.6);
        
       patch([r*cos(phi),r*cos(fliplr(phi))],...
             [r*sin(phi),r*sin(fliplr(phi))],...
             [zeros(size(phi)),h*ones(size(phi))],...
             [1 1 1]*.6);
         
       patch([0,.99*r*cos(phi)],[0,.99*r*sin(phi)],[0,zeros(size(phi))],...
             [1 1 1]*.7,'edgecolor','none');
   end
   function makeDispenser(FS,LW)
        d = .2;
        s = .5;
        a = .2;
        H = 1;
        b = .2;
        q = linspace(-pi,0,40);
        patch([-d/2,-d/4,d/4,d/2,d/2,-d/2],...
              zeros(1,6),...
              [a+s,s,s,a+s,a+s+H,a+s+H],...
              [1 1 1]*.8,'linewidth',LW);
        patch([d/2*cos(q),d/2,-d/2],...
              zeros(1, length(q)+2),...
              a+s+b+[d/2*sin(q),H-b, H-b],...
              [1 1 1]*0);
        text(d/2,0,s+a+H/4,'\leftarrow Dispenser','fontsize',FS,...
            'verticalalignment','bottom')
         
   end
   function makeAblob(LW)
        q = linspace(0,2*pi*9/10,10);
        qi = linspace(0,2*pi*9/10,50);
        r = .3+.05*randn(1,10);
        x = r.*cos(q);
        y = r.*sin(q);
        xi = interp1(q,x,qi,'spline');
        yi = interp1(q,y,qi,'spline');
        patch(xi,yi,ones(size(xi))*.02,[0 0 0]);
   end
   function showSpin(FS,LW,AS)
       q = linspace(-pi/2+pi/3,3*pi/2-pi/3,200);
       plot3(.8*cos(q),.8*sin(q),ones(size(q))*.01,'k','linewidth',LW+.5);
       arrow([.8*cos(q(end-1)),.8*sin(q(end-1)),.01],...
             [.8*cos(q(end)),.8*sin(q(end)),.01],AS);
       text(cos(q(end)),sin(q(end)),.01,'\it\omega','fontsize',FS,...
            'horizontalalignment','left','verticalalignment','bottom');
       for i = 1:7
           arrow([0,0,.01],[.55*cos(i*pi/4),.55*sin(i*pi/4),.01],AS,...
                 'linewidth',LW-.5)
           if i == 7
               text(.55*cos(i*pi/4),.55*sin(i*pi/4),.01,...
                    {'Centrifugal';'force'},...
                    'verticalalignment','top',...
                    'horizontalalignment','center',...
                    'fontsize',FS);
           end
       end;
   end
end