function YandNu
% Compute and visualize the Young modulus Y and the Poisson ratio nu
% for Si. 

    % material constants, flexibility matrix S
    s11 =  7.68e-12;
    s12 = -2.14e-12;
    s44 = 12.6e-12;
    l = 0; m = 0; n = 1;   % default directions for a 100 plane
    m2 = 0; n2 = 0;
    threeImportantCases()  % important examples
    pltYvsAngle()
    function threeImportantCases()
        %1: <100>
        l = 0; m = 0; n = 1;
        [Y,nu] = computeYandNu();
        fprintf('For <100> direction, Y = %.1f GPa, nu = %f \n',Y,nu)
        %2: <110>
        l = 0; m = sqrt(2)/2; n = sqrt(2)/2;
        [Y,nu] = computeYandNu();
        fprintf('For <110> direction, Y = %.1f GPa, nu = %f \n',Y,nu)
        %3: <111>
        l = sqrt(3)/3; m = sqrt(3)/3; n = sqrt(3)/3;
        Y = computeYandNu();
        fprintf('For <111> direction, Y = %.1f GPa \n',Y)
    end
    function pltYvsAngle()
        l = 0;
        N = 100; % number of pts for the polar plot
        for k = 0:(N-1)
            q(k+1) = pi/2*k/(N-1)-pi/4;
            m = cos(q(k+1));
            n = cos(pi/2-q(k+1));
            m2 = cos(q(k+1)+pi/2);
            n2 = cos(q(k+1));
            [Y(k+1),nu(k+1)] = computeYandNu();
        end;
        FS = 16;
        pltNuTheta
        pltYpolar;
        pltYtheta;
        pltNupolar;
        function pltNuTheta()
            figure
            plot((q+pi/4)*180/pi,nu,'k','linewidth',3);
            set(gca,'fontsize',FS,'xlim',[0,90],'xtick',[0:15:90])
            xlabel('Angle \it\theta \rm [deg]');
            ylabel('Poisson ratio \it\nu');
            title(['-\itY\rm[(\itS\rm_{12}+(\itS\rm_{11}-\itS\rm_{12}-',...
                   '\itS\rm_{44}/2)(2cos^2(\it\theta\rm)sin^2(\it\theta\rm))]'])
            grid
            axes('position',[.37 .35 .3 .3]);
            qW = linspace(-pi/2+pi/6,3*pi/2-pi/6,100);
            patch(cos(qW),sin(qW),[1 1 1]*.8)
            hold on;
            qL = linspace(0,pi/4,20);
            plot(.5*cos(qL),.5*sin(qL),'k','linewidth',1.5);
            plot([0,.7],[0 0],'k');
            plot([0,.7/sqrt(2)],[0,.7/sqrt(2)],'k');
            plot([0,.7/sqrt(2)],[0,-.7/sqrt(2)],'k');
            arrow([.5*cos(qL(end-1)),.5*sin(qL(end-1))],...
                  [.5*cos(qL(end)),.5*sin(qL(end))],10)
            text(cos(pi/12)/2,sin(pi/12)/2,'\it\theta  ','fontsize',FS-2,...
                'horizontalalignment','right');
            text(0,.6,'100 Wafer','fontsize',FS-2,'horizontalalignment','center')
            text(0,-cos(pi/8),{'\uparrow';'[110]\rightarrow'},'fontsize',FS-2,...
                 'verticalalignment','bottom',...
                 'horizontalalignment','center')
            axis equal
            axis off
        end
        function pltYtheta()
            
            figure
            plot((q+pi/4)*180/pi,Y,'k','linewidth',3);
            set(gca,'fontsize',FS,'xlim',[0,90],'xtick',[0:15:90])
            xlabel('Angle \it\theta \rm [deg]');
            ylabel('Young modulus [GPa]');
            title(['[\itS\rm_{11}-2[(\itS\rm_{11}-\itS\rm_{12})-\itS\rm_{44}/2]',...
                   'cos^2(\it\theta\rm)sin^2(\it\theta\rm)]^{-1}']);
            grid
            axes('position',[.37 .35 .3 .3]);
            qW = linspace(-pi/2+pi/6,3*pi/2-pi/6,100);
            patch(cos(qW),sin(qW),[1 1 1]*.8)
            hold on;
            qL = linspace(0,pi/4,20);
            plot(.5*cos(qL),.5*sin(qL),'k','linewidth',1.5);
            plot([0,.7],[0 0],'k');
            plot([0,.7/sqrt(2)],[0,.7/sqrt(2)],'k');
            arrow([.5*cos(qL(end-1)),.5*sin(qL(end-1))],...
                  [.5*cos(qL(end)),.5*sin(qL(end))],10)
            text(cos(pi/12)/2,sin(pi/12)/2,'\it\theta  ','fontsize',FS-2,...
                'horizontalalignment','right');
            text(0,.6,'100 Wafer','fontsize',FS-2,'horizontalalignment','center')
            text(0,-cos(pi/8),{'\uparrow';'[110]\rightarrow'},'fontsize',FS-2,...
                 'verticalalignment','bottom',...
                 'horizontalalignment','center')
            axis equal
            axis off
        end
        function pltYpolar()
            figure
            plot(cos(q+pi/4).*Y,sin(q+pi/4).*Y,'k','linewidth',3);
            hold on;
            axis equal
            dY = [0:40:200];
            set(gca,'xlim',dY([1,end]),'xtick',dY(1:end-1),'ylim',dY([1,end]),...
                'ytick',dY(1:end-1),'fontsize',FS);
            for dYc = dY
                plot(dYc*cos(q+pi/4),dYc*sin(q+pi/4),'k:')
            end;
            for dq = [0:15:90]*pi/180
                plot([0, cos(dq)]*dY(end),[0, sin(dq)]*dY(end),'k:')
                text(cos(dq)*mean(dY(end-1:end)),sin(dq)*mean(dY(end-1:end)),...
                     [' ' num2str(round(dq*180/pi)) '^o'],'fontsize',FS,...
                     'rotation',dq*180/pi,...
                     'verticalalignment','bottom')
            end;
            arrow([40 0],[80 0],15,'linewidth',2);
      
            text(80,0,'<1 1 0>',...
                 'fontsize',FS-2,...
                 'verticalalignment','bottom')
            arrow([0 40],[0 80],15,'linewidth',2);
            text(0,80,'<1 1 0>',...
                 'fontsize',FS-2,...
                 'verticalalignment','top',...
                 'rotation',90)
            
            arrow([40 40]/sqrt(2),[80 80]/sqrt(2),15,'linewidth',2);
            text([40 40]/sqrt(2),[80 80]/sqrt(2),...
                 ' <1 0 0>',...
                 'fontsize',FS-2,...
                 'verticalalignment','top',....
                 'rotation',45)    
             box off
            title('Polar plot of Young modulus \itY\rm [GPa]')
            xlabel('Young modulus along [1 1 0] GPa');
            ylabel('Young modulus along [1 1 0] GPa');
        end
      function pltNupolar()
            figure
            plot(cos(q+pi/4).*nu,sin(q+pi/4).*nu,'k','linewidth',3);
            hold on;
            axis equal
            dY = [0:.06:.3];
            set(gca,'xlim',dY([1,end]),'xtick',dY(1:end-1),'ylim',dY([1,end]),...
                'ytick',dY(1:end-1),'fontsize',FS);
            for dYc = dY
                plot(dYc*cos(q+pi/4),dYc*sin(q+pi/4),'k:')
            end;
            for dq = [0:15:90]*pi/180
                plot([0, cos(dq)]*dY(end),[0, sin(dq)]*dY(end),'k:')
                text(cos(dq)*mean(dY(end-1:end)),sin(dq)*mean(dY(end-1:end)),...
                     [' ' num2str(round(dq*180/pi)) '^o'],'fontsize',FS,...
                     'rotation',dq*180/pi,...
                     'verticalalignment','bottom')
            end;
            arrow([.5 0]*.1,[1 0]*.1,15,'linewidth',2);
      
            text(1*.1,0,'<1 1 0>',...
                 'fontsize',FS-2,...
                 'verticalalignment','bottom')
            arrow([0 0.5]*.1,[0 1]*.1,15,'linewidth',2);
            text(0,1*.1,'<1 1 0>',...
                 'fontsize',FS-2,...
                 'verticalalignment','top',...
                 'rotation',90)
            
            arrow([1 1]/2/sqrt(2)*.1,[1 1]/sqrt(2)*.1,15,'linewidth',2);
            text([1 1]/2/sqrt(2)*.1,[1 1]/sqrt(2)*.1,...
                 ' <1 0 0>',...
                 'fontsize',FS-2,...
                 'verticalalignment','top',....
                 'rotation',45)    
             box off
            title('Polar plot of Poisson ratio \it\nu\rm')
%             xlabel('Young modulus along [1 1 0] GPa');
%             ylabel('Young modulus along [1 1 0] GPa');
      end
    end
    function [Y,nu] = computeYandNu()      
        Y = 1/(s11-2*(s11-s12-s44/2)*(m^2*n^2+n^2*l^2+m^2*l^2));
        l1 = l; m1 = m; n1 = n;
        l2 = l; m2 = -n; n2 = m;
        nu = -Y*(s12+(s11-s12-s44/2)*(l1^2*l2^2+m1^2*m2^2+n1^2*n2^2));
        Y = Y*1e-9; % express the Young modulus in GPa
    end
end