function beamGeometry

        L = 1;
        w = .2;
        d = .05;
        uL = 1;
        fs = 9;
        setFigure
        beamColor = [1 1 1]*.9;
        patch([0 0 0 0],[-1 1 1 -1]*L/4,[-1 -1 1 1]*L/4,[1 1 1]*.8,'edgecolor','none'); % draw wall
        drawRefBeamPosition(L, w, d, [1 1 1],'-');
        deformedBeam(L,w,d, uL, beamColor)
        
        axis 'off'
        annotation('arrow',[1 1]*.8, [.4 .32])
        annotation('arrow',[1 1]*.8, [.54 .44])
        text(L,0,-.12,'\itu_y\rm(\itx=L\rm)','fontsize',fs)
        text(L,0,.12,'\itf_y\rm','fontsize',fs)
        annotation('doublearrow',[0.1857 0.2643],[0.6371 0.7071])
        text(0,-.05,.1,'\itw\rm','fontsize',fs);
        annotation('doublearrow',[0.1857 0.7661],[0.6347 0.4071]);
        text(L/2,-.05,.05,'\itL','fontsize',fs);
        annotation('arrow',[0.175 0.175],[0.6585 0.6143])
        annotation('arrow',[0.175 0.175],[0.53 0.5762])
        text(0,-.16,.02,'\ith','fontsize',fs)
        
return

function setFigure

    fName = 'DeflectedBeam';
    fH    = findobj('name',fName)
    if isempty(fH)
        figure('name',fName,'numbertitle','off','color',[1 1 1]);
    else
        figure(fH);clf
    end;

return

function deformedBeam(L,w,d, uL, beamColor)

    N = 20;
    x = [0:1/N:1]*L;
    u = -3/2/L^2*uL*x.^2 + uL/2/L^3*x.^3;
    patch([x,fliplr(x)],[ones(1,N+1),-ones(1,N+1)]*w/2,[u, fliplr(u)]*w/2,...
          beamColor,'facealpha',1)

return

function drawRefBeamPosition(L, w, d, beamColor, lineStyle)

    p(1) = patch([0 L L 0],[-1 -1 -1 -1]*w/2,[-1 -1 1 1]*d/2,beamColor); % side surface
    p(2) = patch([0 L L 0],[1 1 1 1]*w/2,[-1 -1 1 1]*d/2,beamColor); % side surface
    p(3) = patch([0 L L 0],[-1 -1 1 1]*w/2,[-1 -1 -1 -1]*d/2,beamColor);
    p(4) = patch([0 L L 0],[-1 -1 1 1]*w/2,[1 1 1 1]*d/2,beamColor);
    p(5) = patch([1 1 1 1]*L,[-1 1 1 -1]*w/2,[-1 -1 1 1]*d/2,beamColor);
           patch([0 L L 0],[-1 -1 1 1]*w/2,[0 0 0 0],[1 1 1 ],'linestyle',':','facealpha',.5)
    
    set(p,'linestyle',lineStyle,'facealpha',.2,'linewidth',1,'facealpha',.5)
    view(34, 26)
    axis 'equal'

return