function gyroColor
    
    setFigure('Gyro geometry')
    drawSenseElectrodes;
    drawSenseSprings
    drawFrame
    drawDriveSprings
    drawDriveElectrodes
    drawDriveSenseElectrodes
    axis equal
    axis off
    set(gcf,'renderer','zbuffer','color',[1 1 1]*.4)
    customLenged
    
return

function out = defGeometry

    out = ['Ncs = 5;',...   % number of Coriolis electrodes
          '  g = 3;',...     % gap
          ' bw = 2;',...     % beam width
          'Lcs = 120;',...    % beam length
          'HcsTree = 10;',...
          'ccs = [1 0 0]*.9;',...% color of Coriolis sense
          'ccs2 = [0 1 0]*.8;',...
          'ccs3 = [1 1 1];',...
          'cd1  = [.5 .5 0];',...
          'cd2  = [0 .5 .5];',...
          'cds1 = [1 .5 0];',...
          'cds2 = [1 1 1]*.9;',...
          'cf   = [1 .5 1]*.9;',...
          'wSSpring = 30;',...
          'hSSpring = 3:5;',...
          'Li = (Lcs-HcsTree)/2+HcsTree/2+2*g;',...
          'Lo = Li + HcsTree;',...
          'yL = 7*bw-sum(hSSpring)-sum(hSSpring(1:2));',...
          'yH = (bw/2+g+Ncs*(3*g+3*bw))+7*bw+sum(hSSpring([1:3,1:2]));',... 
          'yLL = yL - HcsTree;',...
          'yHH = yH + HcsTree;',...
          'Nd = 4;',...
          'Ld = 12;',...
          'dL = 40;'...
          'dY = 50;',...
          'Nds = 2;',...
          'FS = 15;',...
          ];

return

function drawSenseElectrodes

    eval(defGeometry)
   
    for i = 1:Ncs
        patch([-1 1 1 -1]*Lcs/2,...
              [-1 -1 1 1]*bw/2+bw+2*g+i*(3*g+3*bw),...
              ccs,...
              'edgecolor','none');
%         patch([0 1 1 0]*(Lcs-HcsTree)/2+HcsTree/2+2*g,...
%               [-1 -1 1 1]*bw/2+g+i*(3*g+3*bw),...
%               ccs2,...
%               'edgecolor','none');
%         patch(-[0 1 1 0]*(Lcs-HcsTree)/2-HcsTree/2-2*g,...
%               [-1 -1 1 1]*bw/2+g+i*(3*g+3*bw),...
%               ccs2,...
%               'edgecolor','none');
        patch([0 1 1 0]*(Lcs-HcsTree)/2+HcsTree/2+2*g,...
              [-1 -1 1 1]*bw/2+2*bw+3*g+i*(3*g+3*bw),...
              ccs3,...
              'edgecolor','none');
        patch(-[0 1 1 0]*(Lcs-HcsTree)/2-HcsTree/2-2*g,...
              [-1 -1 1 1]*bw/2+2*bw+3*g+i*(3*g+3*bw),...
              ccs3,...
              'edgecolor','none');
    end;
    patch([-1 1 1 -1]*HcsTree/2,...
          [0 0 1 1]*(bw/2+g+Ncs*(3*g+3*bw))+7*bw,...
          ccs,'edgecolor','none');
      
   %bottom spring

return

function drawSenseSprings

    eval( defGeometry )
    [x,y] = createSingleSenseSpring;
    patch(x+HcsTree/2,7*bw+y-sum(hSSpring)-sum(hSSpring(1:2)),...
          ccs,'edgecolor',ccs);
    patch(-x-HcsTree/2,7*bw+y-sum(hSSpring)-sum(hSSpring(1:2)),...
          ccs,'edgecolor',ccs);
    patch(x+HcsTree/2,7*bw+y+(bw/2+g+Ncs*(3*g+3*bw)),...
          ccs,'edgecolor',ccs);
    patch(-x-HcsTree/2,7*bw+y+(bw/2+g+Ncs*(3*g+3*bw)),...
          ccs,'edgecolor',ccs);

return

function [x,y] = createSingleSenseSpring

    eval( defGeometry )
    
    x = [0, 0, wSSpring, wSSpring, 0, 0];
    x = [x, fliplr(x)-bw];
    y = [0, cumsum(hSSpring), hSSpring(2)+sum(hSSpring),...
        sum(hSSpring(1:2))+sum(hSSpring),...
        sum(hSSpring(1:2))+sum(hSSpring),...
        sum(hSSpring)+hSSpring(2)-bw,...
        sum(hSSpring)-bw,...
        sum(hSSpring(1:2))+bw,...
        hSSpring(1)+bw,0];
    

return

function [x,y] = createSpringShadow

    eval( defGeometry )
    hSSpring(3) = hSSpring(3) + 2*g;
    
    x = [0, wSSpring + bw, wSSpring + bw, 0]+bw;
   
    y = [ cumsum(hSSpring([1:3,2]))];
    

return

function drawFrame

    eval( defGeometry );
    
    x = [-Li,Li,Li,-Li,-Li,-Lo,Lo,Lo,-Lo,-Lo];
    y = [yL, yL, yH, yH,yL, yLL, yLL, yHH, yHH, yLL];
    patch(x,y,ccs,'edgecolor',ccs);
    [xS,yS] = createSpringShadow;
     
    
    xf = [fliplr(yS) + Lo-g, -yS-Lo+g, fliplr(-yS)-Lo+g,...
          yS + Lo-g,yS(end)+Lo-g, Lo+dL,-Lo-dL,-Lo-dL,Lo+dL, Lo+dL ];
    yf = [fliplr(xS) + yHH + g,xS + yHH + g, ...
          fliplr(-xS) + yLL - g,-xS + yLL - g,...
          xS(end)+yHH+g,yHH+dY, yHH+dY,yLL-dY,yLL-dY,yHH+dY];
    
    patch(xf,yf,cf,'edgecolor',cf);
    
return

function drawDriveSprings

    eval(defGeometry)
    [x,y] = createSingleSenseSpring;
    patch(y+Lo,x+yHH,ccs,'edgecolor',ccs);
    patch(y+Lo,-x+yLL,ccs,'edgecolor',ccs);
    patch(-y-Lo,x+yHH,ccs,'edgecolor',ccs);
    patch(-y-Lo,-x+yLL,ccs,'edgecolor',ccs);

return

function drawDriveElectrodes

    eval( defGeometry )
    
    for i = 1:Nd
%         patch(Lo + [0 1 1 0]*Ld,...
%               [0 0 1 1]*bw+yL + (i-1)*(2*bw + 2*g),...
%               ccs,'edgecolor',ccs);  % struct
%         patch(Lo + [0 1 1 0]*Ld,...
%               -[0 0 1 1]*bw+yH - (i-1)*(2*bw + 2*g),...
%               ccs,'edgecolor',ccs);
        patch(-Lo - [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-1)*(2*bw + 2*g),...
              ccs,'edgecolor',ccs);  % struct
        patch(-Lo - [0 1 1 0]*Ld,...
              -[0 0 1 1]*bw+yH - (i-1)*(2*bw + 2*g),...
              ccs,'edgecolor',ccs);
    end
    for i = 1:Nd+1
%         patch(Lo +sum(hSSpring([1:3,1:2]))- [0 1 1 0]*Ld,...
%               [0 0 1 1]*bw+yL + (i-1)*(2*bw + 2*g)- g-bw,...
%               cd1,'edgecolor',cd1);  
%         patch(Lo +sum(hSSpring([1:3,1:2]))- [0 1 1 0]*Ld,...
%               -[0 0 1 1]*bw+yH - (i-1)*(2*bw + 2*g) + g+bw,...
%               cd1,'edgecolor',cd1); 
        patch(-Lo -sum(hSSpring([1:3,1:2]))+ [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-1)*(2*bw + 2*g)- g-bw,...
              cd2,'edgecolor',cd2);  
        patch(-Lo -sum(hSSpring([1:3,1:2]))+[0 1 1 0]*Ld,...
              -[0 0 1 1]*bw+yH - (i-1)*(2*bw + 2*g) + g+bw,...
              cd2,'edgecolor',cd2);  
    end;

return

function drawDriveSenseElectrodes

    eval( defGeometry )
    D = 1;
    for i = 1:Nds
        patch(Lo + [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-D)*(2*bw + 2*g)+(yHH+yLL)/2,...
              ccs,'edgecolor',ccs);  % struct
%         patch(-Lo - [0 1 1 0]*Ld,...
%               [0 0 1 1]*bw+yL + (i-D)*(2*bw + 2*g)+(yHH+yLL)/2,...
%               ccs,'edgecolor',ccs);  % struct
    end
    for i = 1:Nds+1
        patch(Lo +sum(hSSpring([1:3,1:2]))- [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-D)*(2*bw + 2*g)- g-bw+(yHH+yLL)/2,...
              cds1,'edgecolor',cds1);  
%         patch(-Lo -sum(hSSpring([1:3,1:2]))+ [0 1 1 0]*Ld,...
%               [0 0 1 1]*bw+yL + (i-D)*(2*bw + 2*g)- g-bw+(yHH+yLL)/2,...
%               cds2,'edgecolor',cds2);  
    end;

return

function customLenged
% 
    eval(defGeometry)
    legString = {'Structure ','Coriolis sense ',...
                 'Drive ','Drive Sense ', 'Substrate '};
    col = {ccs; ccs3; cd2; cds1; cf};
    patch(-Lo-5*dL + [0 1 1 0]*4*dL,yLL-dY + [0 0 1 1]*(yHH-yLL+2*dY),[1 1 1],...
        'edgecolor',[1 1 1]);
    for i = 1:length(col)
        patch(-Lo-2*dL+[0 1 1 0]*dL/2, yL+(i-1)*dL/2+[0 0 1 1]*dY/5,col{i})
        text(-Lo-2*dL, yL+(i-1)*dL/2+dY/10, legString{i},'fontsize',FS,...
         'horizontalalignment','right');
     
    end;
    applyhatch(gcf,'/x|\');
    set(gcf,'position',get(gcf-1,'position'))
return

