function gyroSurf
    
    setFigure('Gyro geometry')
    drawSenseElectrodes;
    drawSenseSprings
    drawFrame
    drawDriveSprings
    drawDriveElectrodes
    drawDriveSenseElectrodes
    axis equal
    axis off
    set(gcf,'renderer','zbuffer','color',[1 1 1]*.4)
    
return

function out = defGeometry

    out = ['Ncs = 5;',...   % number of Coriolis electrodes
          '  g = 3;',...     % gap
          ' bw = 2;',...     % beam width
          'Lcs = 120;',...    % beam length
          'HcsTree = 10;',...
          'ccs = [1 1 1]*.9;',...% color of Coriolis sense
          'ccs2 = [1 1 1]*.8;',...
          'ccs3 = [1 1 1]*.7;',...
          'wSSpring = 30;',...
          'hSSpring = 3:5;',...
          'Li = (Lcs-HcsTree)/2+HcsTree/2+2*g;',...
          'Lo = Li + HcsTree;',...
          'yL = 7*bw-sum(hSSpring)-sum(hSSpring(1:2));',...
          'yH = (bw/2+g+Ncs*(3*g+3*bw))+7*bw+sum(hSSpring([1:3,1:2]));',... 
          'yLL = yL - HcsTree;',...
          'yHH = yH + HcsTree;',...
          'Nd = 4;',...
          'Ld = 12;',...
          'dL = 40;'...
          'dY = 50;',...
          'Nds = 2;',...
          ];

return

function drawSenseElectrodes

    eval(defGeometry)
   
    for i = 1:Ncs
        surf([-1 1 1 -1]*Lcs/2,...
              [-1 -1 1 1]*bw/2+bw+2*g+i*(3*g+3*bw),...
              ccs,...
              'edgecolor','none');
        surf([0 1 1 0]*(Lcs-HcsTree)/2+HcsTree/2+2*g,...
              [-1 -1 1 1]*bw/2+g+i*(3*g+3*bw),...
              ccs2,...
              'edgecolor','none');
        surf(-[0 1 1 0]*(Lcs-HcsTree)/2-HcsTree/2-2*g,...
              [-1 -1 1 1]*bw/2+g+i*(3*g+3*bw),...
              ccs2,...
              'edgecolor','none');
        surf([0 1 1 0]*(Lcs-HcsTree)/2+HcsTree/2+2*g,...
              [-1 -1 1 1]*bw/2+2*bw+3*g+i*(3*g+3*bw),...
              ccs3,...
              'edgecolor','none');
        surf(-[0 1 1 0]*(Lcs-HcsTree)/2-HcsTree/2-2*g,...
              [-1 -1 1 1]*bw/2+2*bw+3*g+i*(3*g+3*bw),...
              ccs3,...
              'edgecolor','none');
    end;
    surf([-1 1 1 -1]*HcsTree/2,...
          [0 0 1 1]*(bw/2+g+Ncs*(3*g+3*bw))+7*bw,...
          ccs,'edgecolor','none');
      
   %bottom spring

return

function drawSenseSprings

    eval( defGeometry )
    [x,y] = createSingleSenseSpring;
    surf(x+HcsTree/2,7*bw+y-sum(hSSpring)-sum(hSSpring(1:2)),...
          ccs,'edgecolor',ccs);
    surf(-x-HcsTree/2,7*bw+y-sum(hSSpring)-sum(hSSpring(1:2)),...
          ccs,'edgecolor',ccs);
    surf(x+HcsTree/2,7*bw+y+(bw/2+g+Ncs*(3*g+3*bw)),...
          ccs,'edgecolor',ccs);
    surf(-x-HcsTree/2,7*bw+y+(bw/2+g+Ncs*(3*g+3*bw)),...
          ccs,'edgecolor',ccs);

return

function [x,y] = createSingleSenseSpring

    eval( defGeometry )
    
    x = [0, 0, wSSpring, wSSpring, 0, 0];
    x = [x, fliplr(x)-bw];
    y = [0, cumsum(hSSpring), hSSpring(2)+sum(hSSpring),...
        sum(hSSpring(1:2))+sum(hSSpring),...
        sum(hSSpring(1:2))+sum(hSSpring),...
        sum(hSSpring)+hSSpring(2)-bw,...
        sum(hSSpring)-bw,...
        sum(hSSpring(1:2))+bw,...
        hSSpring(1)+bw,0];
    

return

function [x,y] = createSpringShadow

    eval( defGeometry )
    hSSpring(3) = hSSpring(3) + 2*g;
    
    x = [0, wSSpring + bw, wSSpring + bw, 0]+bw;
   
    y = [ cumsum(hSSpring([1:3,2]))];
    

return

function drawFrame

    eval( defGeometry );
    
    x = [-Li,Li,Li,-Li,-Li,-Lo,Lo,Lo,-Lo,-Lo];
    y = [yL, yL, yH, yH,yL, yLL, yLL, yHH, yHH, yLL];
    surf(x,y,ccs,'edgecolor',ccs);
    [xS,yS] = createSpringShadow;
     
    
    xf = [fliplr(yS) + Lo-g, -yS-Lo+g, fliplr(-yS)-Lo+g,...
          yS + Lo-g,yS(end)+Lo-g, Lo+dL,-Lo-dL,-Lo-dL,Lo+dL, Lo+dL ];
    yf = [fliplr(xS) + yHH + g,xS + yHH + g, ...
          fliplr(-xS) + yLL - g,-xS + yLL - g,...
          xS(end)+yHH+g,yHH+dY, yHH+dY,yLL-dY,yLL-dY,yHH+dY];
    
    surf(xf,yf,ccs,'edgecolor',ccs);
    
return

function drawDriveSprings

    eval(defGeometry)
    [x,y] = createSingleSenseSpring;
    surf(y+Lo,x+yHH,ccs,'edgecolor',ccs);
    surf(y+Lo,-x+yLL,ccs,'edgecolor',ccs);
    surf(-y-Lo,x+yHH,ccs,'edgecolor',ccs);
    surf(-y-Lo,-x+yLL,ccs,'edgecolor',ccs);

return

function drawDriveElectrodes

    eval( defGeometry )
    
    for i = 1:Nd
        surf(Lo + [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-1)*(2*bw + 2*g),...
              ccs,'edgecolor',ccs);  % struct
        surf(Lo + [0 1 1 0]*Ld,...
              -[0 0 1 1]*bw+yH - (i-1)*(2*bw + 2*g),...
              ccs,'edgecolor',ccs);
        surf(-Lo - [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-1)*(2*bw + 2*g),...
              ccs,'edgecolor',ccs);  % struct
        surf(-Lo - [0 1 1 0]*Ld,...
              -[0 0 1 1]*bw+yH - (i-1)*(2*bw + 2*g),...
              ccs,'edgecolor',ccs);
    end
    for i = 1:Nd+1
        surf(Lo +sum(hSSpring([1:3,1:2]))- [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-1)*(2*bw + 2*g)- g-bw,...
              ccs,'edgecolor',ccs);  
        surf(Lo +sum(hSSpring([1:3,1:2]))- [0 1 1 0]*Ld,...
              -[0 0 1 1]*bw+yH - (i-1)*(2*bw + 2*g) + g+bw,...
              ccs,'edgecolor',ccs); 
        surf(-Lo -sum(hSSpring([1:3,1:2]))+ [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-1)*(2*bw + 2*g)- g-bw,...
              ccs,'edgecolor',ccs);  
        surf(-Lo -sum(hSSpring([1:3,1:2]))+[0 1 1 0]*Ld,...
              -[0 0 1 1]*bw+yH - (i-1)*(2*bw + 2*g) + g+bw,...
              ccs,'edgecolor',ccs);  
    end;

return

function drawDriveSenseElectrodes

    eval( defGeometry )
    D = 1;
    for i = 1:Nds
        surf(Lo + [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-D)*(2*bw + 2*g)+(yHH+yLL)/2,...
              ccs,'edgecolor',ccs);  % struct
        surf(-Lo - [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-D)*(2*bw + 2*g)+(yHH+yLL)/2,...
              ccs,'edgecolor',ccs);  % struct
    end
    for i = 1:Nds+1
        surf(Lo +sum(hSSpring([1:3,1:2]))- [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-D)*(2*bw + 2*g)- g-bw+(yHH+yLL)/2,...
              ccs,'edgecolor',ccs);  
        surf(-Lo -sum(hSSpring([1:3,1:2]))+ [0 1 1 0]*Ld,...
              [0 0 1 1]*bw+yL + (i-D)*(2*bw + 2*g)- g-bw+(yHH+yLL)/2,...
              ccs,'edgecolor',ccs);  
    end;

return

