function torsionalComb

    setFigure('TorsionalSpring')
    q = 1;
    drawAnchor(q)
    drawMovable(q)
    h = get(gca,'children');
    labelTheta(q)
    legend(h(end-9:end-8),{'moving electrode','fixed electrode'},'fontsize',9,...
        'location','northoutside','orientation','horizontal')
    axis equal
    axis off
    set(gca,'position',[.05,.05,.9,.9])
    set(gcf,'renderer','zbuffer')
   set(gcf,'paperposition',[1 1 4 4])
    colormap('gray')
    print -depsc Fig_3p22b
    print -dtiff -r1200 Fig_3p22b
       
return

function out = defGeom

    out = ['N = 5;',... %number of innner electrodes
           'g = 3;',...  % gap between electrodes
           'bw = 3;',...
           'Rin = 50;',...% inner radius
           'Rout = Rin + 2*N*g+(2*N+1)*bw + g;',...%outer radius
           'cFix = [1 1 1]*.7;',... % color of the fixed electrode
           'cFixNoElec = [1 1 1]*.75;',...
           'cMov = [1 1 1]*.5;',...
           'cMovNoElec = [1 1 1]*.5;',...
           'qIn = 2*pi/180;',...
           'qAmov = -10*pi/180;',...
           'DR = 10;',...
           'dy = 4;',...
           'qMov = 15*pi/180;',...  % maximum travel alowed 
           ]; 

return

function drawAnchor(q)

    eval(defGeom)
    qAmov = qAmov*q;
    q = linspace(pi/2,pi,20);
    patch([0 (Rin-g)*cos(q)],[0 (Rin-g)*sin(q)],cFixNoElec,'edgecolor',cFixNoElec); % central hup
    hold on
    patch([0 0 Rout*cos(pi/2+qIn)],...
          [0 Rout Rout*sin(pi/2+qIn)],...
          cFixNoElec,'edgecolor',cFixNoElec);
    
    for i = 1:N+1
        r = Rin + g+2*(i-1)*g + 2*(i-1)*bw;
        qE = linspace(pi/2+qIn, pi-qMov,20);
        patch([r*cos(qE), (r+bw)*cos(fliplr(qE))],...
               [r*sin(qE), (r+bw)*sin(fliplr(qE))],...
               cFix, 'edgecolor',cFix);
    end;  
    patch(69+[0 1 1 0]*20,100+[0 0 1 1]*50,cFix,'edgecolor',cFix)
    
return

function drawMovable(qS)

        eval(defGeom)
qAmov = qAmov*qS;
    q = linspace(pi/2,pi+pi/300,40)+qAmov;
        patch( [(Rout + g)*cos(q), (Rout+g+DR)*cos(fliplr(q))],...
               [(Rout + g)*sin(q), (Rout+g+DR)*sin(fliplr(q))],...
               cMovNoElec,'edgecolor',cMovNoElec); % central hup
        patch(-[[Rin+2*g+bw Rout+g+DR]*cos(qAmov) (Rout+g)*cos(qIn+qAmov) (Rin+2*g+bw)*cos(qIn+qAmov)],...
              [(Rin+2*g+bw)*sin(-qAmov), (Rout+g)*sin(-qAmov), (Rout+g)*sin(qIn-qAmov) (Rin+2*g+bw)*sin(qIn-qAmov)],...
              cMovNoElec,'edgecolor',cMovNoElec); % central hup
    for i = 1:N
        r = Rin +2*g+bw+2*(i-1)*g + 2*(i-1)*bw;
        qE = linspace(pi/2+qMov, pi-qIn,20)+qAmov;
        patch([r*cos(qE), (r+bw)*cos(fliplr(qE))],...
               [r*sin(qE), (r+bw)*sin(fliplr(qE))],...
               cMov, 'edgecolor',cMov);
    end;
    if qS
        spiral3d(45,Rout+g+DR/2,10,20)
    else
        a =1 
        spiral3d(35,Rout+g+DR/2,10,41)
    end
  
    
return

function labelTheta(q)
fs = 9;
    if q
        eval(defGeom);
    q = linspace(pi,pi+qAmov,10);
    r = Rout;
    ind1 = length(q)-1;
    ind2 = ind1+1;
    
           plot(r*cos(q),r*sin(q),'-k');
           arrow( [r*cos(q(ind1)),r*sin(q(ind1))],...
               [r*cos(q(ind2)),r*sin(q(ind2))],10)
           text(r*cos(mean(q)),r*sin(mean(q)),' \it\theta','fontsize',fs)
           plot([0, (r+DR)*cos(q(1))],[0 (r+DR)*sin(q(1))],'--k');
           
           % label R1
           R1 = Rin + 2*g + 3/2*bw;
           arrow( [R1/2*cos(pi)+2*dy, R1*sin(pi)-dy],[0,-dy],10)
           arrow( [R1/2*cos(pi)-dy, R1*sin(pi)-dy],[-R1,-dy],10)
           plot([0 0],[0 -2*dy],'k');
           plot(-[1 1]*R1,[0 -2*dy],'k');
           text(R1/2*cos(pi),R1*sin(pi),'\itR\rm_1','fontsize',fs,...
                'verticalalignment','top')
            q = linspace(pi,pi/2,10);
           plot(R1*cos(q),R1*sin(q),'k:');
            
           % label g
           DR = 2*g+2*bw;
           R1g = R1 + 7*bw/2;
           R2 = R1g+3*g;
           R3 = R2 + g;
           R4 = R3+3*g;
           arrow( [R1g*cos(pi+2*qAmov), R1g*sin(pi+2*qAmov)],...
                  [R2*cos(pi+2*qAmov), R2*sin(pi+2*qAmov)],10)
           arrow( [R4*cos(pi+2*qAmov), R4*sin(pi+2*qAmov)],...
                  [R3*cos(pi+2*qAmov), R3*sin(pi+2*qAmov)],10)
           text(1/2*(R2+R4)*cos(pi+qAmov),1/2*(R2+R4)*sin(pi+qAmov),'\itd\rm','fontsize',fs,...
                'verticalalignment','top')
           % label w
           DR = 2*g+2*bw;
           R1g = R1 + 5*bw/2;
           R2 = R1g+3*g;
           R3 = R2 + g;
           R4 = R3+3*g;
           alph = pi/2-qAmov;
           arrow( [R1g*cos(alph), R1g*sin(alph)],...
                  [R2*cos(alph), R2*sin(alph)],10)
           arrow( [R4*cos(alph), R4*sin(alph)],...
                  [R3*cos(alph), R3*sin(alph)],10)
           text(1/2*(R2+R4)*cos(pi/2),1/2*(R2+R4)*sin(pi/2),'\itw','fontsize',fs,...
                'verticalalignment','top')
                  plot( [0,(Rout+2.5*DR)*cos(pi/2+qMov)],...
              [0,(Rout+2.5*DR)*sin(pi/2+qMov)],'k');
        plot( [0,(Rout+2.5*DR)*cos(pi-qMov)],...
              [0,(Rout+2.5*DR)*sin(pi-qMov)],'k');
        q = linspace(pi/2+qMov,pi-qMov,50);
        
        plot( (Rout+2*DR)*cos(q),(Rout+2*DR)*sin(q),'k');
        plot( [0,(Rout+2.5*DR)*cos(q(1)+qAmov)],[0,(Rout+2.5*DR)*sin(q(1)+qAmov)],'k');
        text((Rout+3*DR)*cos(3*pi/4),(Rout+3*DR)*sin(3*pi/4),'\it\theta\rm_o  ','fontsize',fs)
        arrow([(Rout+2*DR)*cos(q(end-1)),(Rout+2*DR)*sin(q(end-1))],...
            [(Rout+2*DR)*cos(q(end)),(Rout+2*DR)*sin(q(end))])
        arrow([(Rout+2*DR)*cos(q(2)),(Rout+2*DR)*sin(q(2))],...
            [(Rout+2*DR)*cos(q(1)),(Rout+2*DR)*sin(q(1))])
        q = linspace(pi/2+qMov,pi/2+qMov+qAmov,50);
        plot( (Rout+2*DR)*cos(q),(Rout+2*DR)*sin(q),'k');
        arrow([(Rout+2*DR)*cos(q(end-1)),(Rout+2*DR)*sin(q(end-1))],...
            [(Rout+2*DR)*cos(q(end)),(Rout+2*DR)*sin(q(end))])
                text((Rout+2.8*DR)*cos(pi/2+qMov+qAmov/2),...
                    (Rout+2.8*DR)*sin(pi/2+qMov+qAmov/2),...
                    '\it\theta\rm','fontsize',fs,'horizontalalignment','center')

    else
        eval(defGeom)
        plot( [0,(Rout+2.5*DR)*cos(pi/2+qMov)],...
              [0,(Rout+2.5*DR)*sin(pi/2+qMov)],'k');
        plot( [0,(Rout+2.5*DR)*cos(pi-qMov)],...
              [0,(Rout+2.5*DR)*sin(pi-qMov)],'k');
        q = linspace(pi/2+qMov,pi-qMov,50);
        
        plot( (Rout+2*DR)*cos(q),(Rout+2*DR)*sin(q),'k');
        text((Rout+2.8*DR)*cos(3*pi/4),(Rout+2.8*DR)*sin(3*pi/4),'\it\theta\rm_o','fontsize',fs)
        arrow([(Rout+2*DR)*cos(q(end-1)),(Rout+2*DR)*sin(q(end-1))],...
            [(Rout+2*DR)*cos(q(end)),(Rout+2*DR)*sin(q(end))])
        arrow([(Rout+2*DR)*cos(q(2)),(Rout+2*DR)*sin(q(2))],...
            [(Rout+2*DR)*cos(q(1)),(Rout+2*DR)*sin(q(1))])
    end;
         

return