function osc
    [m,k] = systemParameters;
    wo = sqrt(k/m);
    fprintf('fo [kHz] = %f\n',wo/2/pi*1e-3);
    tEnd = 10*(2*pi/wo);
%     options = odeset('RelTol',1e-4,'AbsTol',[1e-4 1e-4 1e-5]);
    [time,X] = ode45(@oscModel,[0 tEnd],[0 .3 0]);
    plot(time,X(:,2))
    
return

function dxdt = oscModel(t,x)

    [m,k,b,Co,R,alpha,beta] = systemParameters;
    [L,w,d] = defGeometry;
    eps0 = defMatConsts;
    vout = beta*tanh( alpha*x(1) );
    N = 5*eps0*w*L/d^2;
    dxdt =[-b/m, N^2/m, -N^2/m;
           1/Co,-1/R/Co,0;
           k*N^2,0,0]*x -[0; vout/R/Co;0];
return

function [m,k,b,Co,R,alpha,beta] = systemParameters

    [L,w,d,h] = defGeometry;
    [eps0,Y,rho] = defMatConsts;
    m = 1/3*rho*w*h*L/3;
    k = .25*Y*w*h^3/(L^3);
    Q = 10;
    b = sqrt(k*m)/Q;
    Co = eps0*w*L/d;
    R = 100e3;
    alpha = 10;
    beta = 1;

return

function [L,w,d,h] = defGeometry

    L = 100e-6; 
    w = 5e-6;
    h = 1e-6;
    d = 1-6;
    
return

function [eps0,Y,rho] = defMatConsts

    rho = 2330;
    Y = 150e9;
    eps0 = 8.854e-12;

return

