function MDFode

    global K invM B N w
    [K,invM,B,N,w,v] = getMDF;
    
    m = 2;
    uo = [1e-6* v(:,m)/max(abs(v(:,m))); zeros(N,1)];
    [t,y] = ode45(@MDF,[0, 10*2*pi/w(m)],uo);  
    figure
    plot(t*1e6,y(:,[N/2,N])*1e6, 'linewidth',2)
    legend('\iti = N/\rm2','\iti = N');
    set(gca,'fontsize',16)
    xlabel('Time \itt\rm [\mus]')
    ylabel('Displacement \itu\rm [\mum]');
    grid
    
return

function qDot = MDF(t,q)
    global K invM B N w

    D = [zeros(N,N),eye(N);...
        -invM*K, -invM*B];
%     fvec = zeros(2*N,1);
%     fvec(end) = 1;
    qDot = D*q; %+zeros(N,N);invM]*fvec*cos(w(1)*t) ;

return

function [K,invM,B,n,w,v] = getMDF

     g = setGeometry;
    mp = setMatProp;
     n = 6; % discretization level (mesh)
     % compute mass matrix
     M = eye(n)*mp.rho*g.L*g.h*g.w/n;
     % compute the flexibilit matrix A (A = inv(K))
     A = zeros(n,n);
     for j = 1:n
         for i = 1:n
             if i>= j 
                A(i,j) = g.L^3/(6*mp.E*g.Ix*n^3)*(3*i*j^2-j^3);
             else
                 A(i,j) = A(j,i);
             end;
         end;
     end;   
     [v,lam] = eig(A*M);
     w = flipud(sqrt(1./diag(lam)));
     v = fliplr(v);
     K = A^(-1);
     zeta = .002;
     B = M*diag(w)*zeta;
     invM = M^(-1);
   
return

function g = setGeometry

    g.L = 40e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  4e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam

return

function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.E = 150e9;  % GPa

return
