function MDFodeForce

    global K invM B N w
    [K,invM,B,N,w,v] = getMDF;
    
    m = 1;
    uo =  zeros(2*N,1);
    [t,y] = ode45(@MDF,[0, 20*2*pi/w(m)],uo);  
    showResults(N,t,y)
    
    
return

function qDot = MDF(t,q)
    global K invM B N w

    D = [zeros(N,N),eye(N);...
        -invM*K, -invM*B];
    fvec = zeros(N,1);
    fvec(end) = 1e-6;
    qDot = D*q+[zeros(N,1); invM*fvec]*cos(w(1)*t) ;

return

function [K,invM,B,n,w,v] = getMDF

     g = setGeometry;
    mp = setMatProp;
     n = 6; % discretization level (mesh)
     % compute mass matrix
     M = eye(n)*mp.rho*g.L*g.h*g.w/n;
     % compute the flexibilit matrix A (A = inv(K))
     A = zeros(n,n);
     for j = 1:n
         for i = 1:n
             if i>= j 
                A(i,j) = g.L^3/(6*mp.E*g.Ix*n^3)*(3*i*j^2-j^3);
             else
                 A(i,j) = A(j,i);
             end;
         end;
     end;   
     [v,lam] = eig(A*M);
     w = flipud(sqrt(1./diag(lam)));
     v = fliplr(v);
     K = A^(-1);
     zeta = .0005;
     B = M*diag(w)*zeta;
     invM = M^(-1);
   
return

function g = setGeometry

    g.L = 40e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  4e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam

return

function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.E = 150e9;  % GPa

return

function showResults(N, t, y)
    figure
    FS = 16;
    set(gca,'colororder',[.5 .5 .5;0 0 0]);
    hold on;
    plot(t*1e6,y(:,[N/2,N])*1e6, 'linewidth',2)
    legend('\iti = n/\rm2','\iti = n');
    set(gca,'fontsize',FS)
    xlabel('Time \itt\rm [\mus]')
    ylabel('Displacement \itu_i\rm [\mum]');
    grid
    ax = findobj('parent',gcf,'type','axes');
    set(ax,'color',[1 1 1]*.85)
    set(gcf,'color',[1 1 1]*.85)
    yl = ylim;
    xl = xlim;
    text(xl(1),yl(2),['\it\omega\rm = 0.9\it\omega\rm_o'],...
        'verticalalignment','bottom',...
        'fontsize',FS)
%     axes('position',[.55 .15 .3 .15])
%     patch([1:N, N:-1:1],[uo(1:N);-uo(N:-1:1)],[1 1 1]*.5);
%     hold on
%     text(N/2,A,'\iti\rm = \itN\rm/2','horizontalalignment','center',...
%                    'verticalalignment','bottom','fontsize',FS)
%     text(N/2,A,'\downarrow','horizontalalignment','center',...
%                    'verticalalignment','top','fontsize',FS)
%     text(N,A,'\iti\rm = \itN','horizontalalignment','center',...
%                  'verticalalignment','bottom','color','k',...
%                  'fontsize',FS)
%     text(N,A,'\downarrow','horizontalalignment','center',...
%                  'verticalalignment','top','color','k',...
%                  'fontsize',FS)
%     axis off
return  
