function MDFodeIC
    global K invM B n w
    [K,invM,B,n,w,v] = getMDF;  
    k = 1;  % mode selection
    uo = [1e-6*v(:,k)/max(abs(v(:,k))); zeros(n,1)];
    [t,y] = ode45(@MDF,[0, 10*2*pi/w(k)],uo); 
    showResults(n, uo, t, y)   
return
function qDot = MDF(t,q)
    global K invM B n w

    D = [zeros(n,n),eye(n);...
        -invM*K, -invM*B];
    qDot = D*q; 
return
function [K,invM,B,n,w,v] = getMDF
     g = setGeometry;
    mp = setMatProp;
     n = 20; % discretization level (mesh)
     M = eye(n)*mp.rho*g.L*g.h*g.w/n;
     A = zeros(n,n);
     for j = 1:n
         for i = 1:n
             if i>= j 
                A(i,j) = g.L^3/(6*mp.E*g.Ix*n^3)*(3*i*j^2-j^3);
             else
                 A(i,j) = A(j,i);
             end;
         end;
     end;   
     [v,lam] = eig(A*M);
     w = flipud(sqrt(1./diag(lam)));
     v = fliplr(v);
     K = A^(-1);
     zeta = 0.0002; % k = 2: zeta = 0.002; k = 1: zeta = 0.0002
     B = M*diag(w)*zeta;
     invM = M^(-1);  
return
function showResults(n, uo, t, y)
    figure
    A = 1.8*abs(uo(n));
    FS = 16;
    set(gca,'colororder',[.5 .5 .5;0 0 0]);
    hold on;
    plot(t*1e6,y(:,[n/2,n])*1e6, 'linewidth',2)
    legend('\iti = n/\rm2','\iti = n');
    set(gca,'fontsize',FS)
    xlabel('Time \itt\rm [\mus]')
    ylabel('Displacement \itu_i\rm [\mum]');
    grid
    axes('position',[.55 .15 .3 .15])
    patch([1:n, n:-1:1],[uo(1:n);-uo(n:-1:1)],[1 1 1]*.5);
    hold on
    text(n/2,A,'\iti\rm = \itn\rm/2','horizontalalignment','center',...
                   'verticalalignment','bottom','fontsize',FS)
    text(n/2,A,'\downarrow','horizontalalignment','center',...
                   'verticalalignment','top','fontsize',FS)
    text(n,A,'\iti\rm = \itn','horizontalalignment','center',...
                 'verticalalignment','bottom','color','k',...
                 'fontsize',FS)
    text(n,A,'\downarrow','horizontalalignment','center',...
                 'verticalalignment','top','color','k',...
                 'fontsize',FS)
    axis off
    set(gcf,'color',[1 1 1]*.85);
    ax = findobj('parent',gcf,'type','axes');
    set(ax,'color',[1 1 1]*.85);
return  
function g = setGeometry

    g.L = 40e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  4e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam

return
function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.E = 150e9;  % GPa

return
