function v= cantBeamMDF_CUP

     
     g = setGeometry;
    mp = setMatProp;
     
     setFigure('MDF clamped Modal')
     
     n = 10;
     [v,w] = computeMDF();
     visModal(diag(w), v,n, 0);
     n = 40; % discretization level (mesh)
     [v,w] = computeMDF();
     visModal(diag(w), v,n, 1);

     colormap('gray')
     set(gcf,'paperposition',[1 1 5 4])
     print -deps Fig_6p20
     print -dtiff -r1200 Fig_6p20
    function [v,w] = computeMDF()
        % compute mass matrix
        M = eye(n)*mp.rho*g.L*g.h*g.w/n;
        % compute the flexibilit matrix A (A = inv(K))
        A = zeros(n,n);
         for j = 1:n
             for i = 1:n
                 if i>= j 
                    A(i,j) = g.L^3/(6*mp.E*g.Ix*n^3)*(3*i*j^2-j^3);
                 else
                     A(i,j) = A(j,i);
                 end;
             end;
         end;  
         % solution: Modal analysis
         [v,w] = eig(A*M);
    end

end

function g = setGeometry

    g.L = 40e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  4e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam

end

function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.E = 150e9;  % GPa

end

function visModal(w, v, n, j)

%     figure('units','normalized','position',[.2 .0 .4 .85]);
    shapeSign = [1,1,-1];  % this just flips the sign of the third mode shape
    
    for i = 1:3   
         axes('position',[.1+j*.5, 1-.28*i, .35, .2])
%          subplot(3,2,2*i-1+j)
         set(gca,'fontsize',9,'ylim',[-1 1]*1.1); hold on;
         plot([.5:n]/(n),shapeSign(i)*v(:,end-i+1)/max(abs(v(:,end-i+1))),...
             '-ko','linewidth',1,'markerfacecolor','k','markersize',3);
         grid off;
         ylabel(['\itf\rm_{' num2str(i) '} = ' ...
                 num2str(1e-6/sqrt(w(end-i+1))/2/pi,'%.1f') ' MHz']);
         if i == 1
             title(['Number of elements \itn\rm = ' num2str(n)])
         end
     end;
     if j == 0
        xlabel({'Normalized length \itx/L';'';'\rm(a)'});
     else
         xlabel({'Normalized length \itx/L';'';'\rm(b)'});
     end
        
     
end