function cantBeamMDFfreq

     g = setGeometry;
    mp = setMatProp;
     n = 20; % discretization level (mesh)
     
     % compute mass matrix
     M = eye(n)*mp.rho*g.L*g.h*g.w/n;
     % compute the flexibilit matrix A (A = inv(K))
     A = zeros(n,n);
     for j = 1:n
         for i = 1:n
             if i>= j 
                A(i,j) = g.L^3/(6*mp.E*g.Ix*n^3)*(3*i*j^2-j^3);
             else
                 A(i,j) = A(j,i);
             end;
         end;
     end;     
     % solution: Modal analysis
     K = inv(A);
     [v,w] = eig(inv(M)*K);   
        ws = diag(sqrt(w));
     % normalized eigenvectors with respect to the mass matrix
     for i = 1:n
         v(:,i) = v(:,i)*sqrt(v(:,i)'*M*v(:,i));
     end;
%      figure, plot(v(:,2)), pause
%        Mn = v'*M*v;
    % define Q
     Q(1) = 10;
     Q(2) = 30;%10*(ws(2)/ws(1))^2;
     Q(3) = 50;
        Q = [Q, ones(1,n-3)*Q(3)]';  
       bn = diag(ws./Q);
        b = v*bn*v';
     % define force location
     f = [zeros(n-1,1); 1];
     % set the points for frequency sweep
     wr = [linspace(0,.9*ws(1),50),...
           linspace(.9*ws(1),1.1*ws(1),300), ...
           linspace(1.1*ws(1),.9*ws(2),50),...
           linspace(.9*ws(2),1.1*ws(2),300),...
           linspace(1.1*ws(2),.9*ws(3),50),...
           linspace(.9*ws(3),1.1*ws(3),300),...
          ];
     j = sqrt(-1);
     for i = 1:length(wr)
          u(i)=f'*inv(-wr(i)^2*M + j*wr(i)*b +inv(A))*f;
     end;
     
     plot(wr/2/pi*1e-6,abs(u)/abs(u(1)),'-k','linewidth',1);
     set(gca,'fontsize',9);
     xlabel('Frequency \itf\rm [MHz]');
     ylabel('Normalized displacement magnitude');
     grid off
     arrow([ws(1)/2/pi*1e-6+2,9],[ws(1)/2/pi*1e-6+.2,9.7],8)
     text(ws(1)/2/pi*1e-6+2,9,' First mode','fontsize',9,...
          'verticalalignment','top')
     arrow([ws(2)/2/pi*1e-6-2,2],[ws(2)/2/pi*1e-6-.1,.7],8)
     text(ws(2)/2/pi*1e-6-2,2,{'Second';' mode'},'fontsize',9,...
         'horizontalalignment','right','verticalalignment','bottom')
     arrow([ws(3)/2/pi*1e-6-2,1.2],[ws(3)/2/pi*1e-6-.1,.2],8)
     text(ws(3)/2/pi*1e-6-2,1.2,' Third mode ','fontsize',9,...
         'horizontalalignment','right','verticalalignment','bottom')
     colormap ('gray')
     set(gcf,'paperposition',[1 1 4 3])
     print -deps Fig_6p23
     print -dtiff -r1200 Fig_6p23
  
return

function g = setGeometry

    g.L = 40e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  4e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam

return

function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.E = 150e9;  % GPa

return

function visModal(w, v,n)

    figure('units','normalized','position',[.2 .1 .4 .85]);
    for i = 1:3     
         subplot(3,1,i)
         set(gca,'fontsize',18,'ylim',[-1 1]*1.1); hold on;
         plot([.5:n]/(n),v(:,end-i+1)/max(abs(v(:,end-i+1))),...
             '-ko','linewidth',2,'markerfacecolor','k');
         grid on;
         ylabel(['\itf\rm_{' num2str(i) '} = ' ...
                 num2str(1e-6/sqrt(w(end-i+1))/2/pi,'%.1f') ' MHz']);
         if i == 1
             title(['Number of elements \itn\rm = ' num2str(n)])
         end
     end;
     xlabel('Normalized length \itx/L');
     
return