function [A,M]=cantBeamMDFmodal

     g = setGeometry;
    mp = setMatProp;
     n = 10; % discretization level (mesh)
     
     % compute mass matrix
     M = eye(n)*mp.rho*g.L*g.h*g.w/n;
     % compute the flexibilit matrix A (A = inv(K))
     A = zeros(n,n);
     for j = 1:n
         for i = 1:n
             if i>= j 
                A(i,j) = g.L^3/(6*mp.E*g.Ix*n^3)*(3*i*j^2-j^3);
             else
                 A(i,j) = A(j,i);
             end;
         end;
     end;   

     % solution: Modal analysis
     tic,[v,w] = eig(A*M);  toc 
     tic,[v1,w1] = eig(A,M);toc
     
     diag(w)
     diag(w1)
     visModal(diag(w), v,n);

return

function g = setGeometry

    g.L = 40e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  4e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam

return

function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.E = 150e9;  % GPa

return

function visModal(w, v,n)

    figure('units','normalized','position',[.2 .1 .4 .85]);
    for i = 1:3     
         subplot(3,1,i)
         set(gca,'fontsize',18,'ylim',[-1 1]*1.1); hold on;
         plot([.5:n]/(n),v(:,end-i+1)/max(abs(v(:,end-i+1))),...
             '-ko','linewidth',2,'markerfacecolor','k');
         grid on;
         ylabel(['\itf\rm_{' num2str(i) '} = ' ...
                 num2str(1e-6/sqrt(w(end-i+1))/2/pi,'%.1f') ' MHz']);
         if i == 1
             title(['Number of elements \itn\rm = ' num2str(n)])
         end
     end;
     xlabel('Normalized length \itx/L');
     
return