function  cantBeamMDFmodalA( m )

    if nargin < 1
        m = 1;
    end;
     g = setGeometry;
    mp = setMatProp;
     n = 40; % discretization level (mesh)
     
     % compute mass matrix
     M = eye(n)*mp.rho*g.L*g.h*g.w/n;
     % compute the flexibilit matrix A (A = inv(K))
     A = zeros(n,n);
     for j = 1:n
         for i = 1:n
             if i>= j 
                A(i,j) = g.L^3/(6*mp.E*g.Ix*n^3)*(3*i*j^2-j^3);
             else
                 A(i,j) = A(j,i);
             end;
         end;
     end;   

     % solution: Modal analysis
     [v,w] = eig(A*M);   
      animMode(diag(w), v, m, n);

return

function g = setGeometry

    g.L = 40e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  4e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam

return

function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.E = 150e9;  % GPa

return

function animMode(w, v, m, n)

    figure('units','normalized','position',[.1 .2 .6 .4]);
    vC = v(:,n-m+1)/max(abs(v(:,n-m+1)));
    nCycles = 10;
    for i = 1:nCycles;
        plotCycle( [0,.5:n]/n, [0;vC] )
    end;
     
return

function plotCycle( x, vC, M )

    if nargin < 3
        M = 10;
    end;

    for i = 1:M
        plot(x, vC*sin(2*pi*i/M),'ko-','linewidth',2,'markerfacecolor', 'k')
        ylabel('normalized displacements');
        xlabel('Normalized length \itx/L');
        set(gca,'ylim',[-1, 1]*max(abs(vC)))
        hold off;
        pause(.1);
    end;

return