function cantBeamMDFsoftClamp

     g = setGeometry;
    mp = setMatProp;
     n = 40; % discretization level (mesh)
     
     % compute mass matrix
     M = eye(n)*mp.rho*g.L*g.h*g.w/n;
     % compute the flexibilit matrix A (A = inv(K))
     A = zeros(n,n);
     kBeam = 1/4*mp.E*g.w*g.h^3/g.L^3;
     kTheta = g.L/(1/180*pi);   % Nominal theta gives rise to 1 deg motion
                                % due to  1 N of force
     cond = 'clamped';
     switch cond
         case 'clamped'
            c0 = 1/(kBeam*1e4);  % for the first mode the factor of hundred
                                 % but k ~ w^2, so for higher modes a
                                 % bigger factor is needed (experiment with
                                 % it).
            theta0 = .1/180*pi;
            c1 = 1/(kTheta/theta0);
         case 'hinged'
            c0 = 1/(kBeam*1e4);  
            theta0 = 180/180*pi;
            c1 = 1/(kTheta/theta0);
         case 'free'
            c0 = 1e4/kBeam;  
            theta0 = 7200/180*pi;
            c1 = 1/(kTheta/theta0);
     end;
  
     for j = 1:n
         for i = 1:n
             if i>= j 
                A(i,j) = g.L^3/(6*mp.E*g.Ix*n^3)*(3*i*j^2-j^3)+c0+g.L*c1*j/n;
             else
                 A(i,j) = A(j,i);
             end;
         end;
     end;   
     % solution: Modal analysis
     [v,w] = eig(A*M);   
      visModal(diag(w), v,n);

return

function g = setGeometry

    g.L = 300e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  5e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam

return

function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.E = 168e9;  % GPa

return

function visModal(w, v,n)

    figure('units','normalized','position',[.2 .1 .4 .8]);
    [w,ind] = sort(w,'descend');
    v = v(:,ind);
    for i = 1:3     
         ord = i;
         subplot(3,1,i)
         set(gca,'fontsize',18,'ylim',[-1 1]*1.1); hold on;
         plot([.5:n]/(n),v(:,ord)/max(abs(v(:,ord))),...
             '-ko','linewidth',2,'markerfacecolor','k');
         grid on;
         ylabel(['\itf\rm_{' num2str(i) '} = ' ...
                 num2str(1e-3/sqrt(w(ord))/2/pi,'%.1f') ' kHz']);
         if i == 1
             title(['Number of elements \itn\rm = ' num2str(n)])
         end
     end;
     xlabel('Normalized length \itx/L');
     
return