function cantBeamMDFstaticForBook

     g = setGeometry;
    mp = setMatProp;
     n = 40; % discretization level (mesh)
     b = 1e-6;
     meff = (33/140+1/70*b/g.L+3*g.L*1/4/(g.L-b)^2)*mp.rho*g.L*g.w*g.h
     keff = mp.E*g.w*g.h^3/4/(g.L-b);
     wAp = sqrt(keff/meff)/2/pi
     % compute mass matrix
     M = eye(n)*mp.rho*g.L*g.h*g.w/n;
     % compute the flexibilit matrix A (A = inv(K))
     A = zeros(n,n);
     for j = 1:n
         for i = 1:n
             if i>= j 
                A(i,j) = g.L^3/(6*mp.E*g.Ix*n^3)*(3*i*j^2-j^3);
             else
                 A(i,j) = A(j,i);
             end;
         end;
     end;     
     % solution: Static displacements
     k= [1,n/2,n];
     for i = 1:3
            f = zeros(n,1);
         f(k(i)) = 1e-5;
            u = A*f;
            set(gca,'ylim',[0 .6],'xlim',[0 1.1]);
            hold on;
            plot([1:n]/n,u*1e6,'k-','marker',mrkr(i),'markersize',6,...
                 'markerfacecolor','k','linewidth',3);
            hold on
            arrow([k(i)/n,u(k(i))*1e6-.08],[k(i)/n,u(k(i))*1e6],20);
            text(k(i)/n,u(k(i))*1e6,[' \iti\rm = ' num2str(k(i))],...
                 'fontsize',18,'verticalalignment','bottom');
     end;
     grid on
     set(gca,'ydir','reverse','fontsize',18,'position',[.15 .15 .8 .7])
     title( ['Force \itf_i\rm = ' num2str(f(k(i))*1e6) ' \muN'])
     xlabel('Normalized length \itx/L')
     ylabel('Displacements  \itu\rm [\mum]') 
return

function g = setGeometry

    g.L = 40e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  4e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam

return

function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.E = 150e9;  % GPa

return

function visModal(w, v,n)

    figure('units','normalized','position',[.2 .1 .4 .85]);
    for i = 1:3     
         subplot(3,1,i)
         set(gca,'fontsize',18,'ylim',[-1 1]*1.1); hold on;
         plot([.5:n]/(n),v(:,end-i+1)/max(abs(v(:,end-i+1))),...
             '-ko','linewidth',2,'markerfacecolor','k');
         grid on;
         ylabel(['\itf\rm_{' num2str(i) '} = ' ...
                 num2str(1e-6/sqrt(w(end-i+1))/2/pi,'%.1f') ' MHz']);
         if i == 1
             title(['Number of elements \itn\rm = ' num2str(n)])
         end
     end;
     xlabel('Normalized length \itx/L');
     
return