function circPlateMDF
   % Roark's formulas for stress and strain, 7th edition p.
    N = 10;                    % discretization level
    L = 200e-6;    h = 1e-6;  % geometry
    d = 1e-6;
    % mat. properties
    Y = 150e9;    nu = .3;    rho = 2330;    D = Y*h^3/12/(1-nu^2);
    a = zeros(N,N);  m = zeros(N,N);
    off = .5;
    f = zeros(N,1);
    f(3) = 1;
    P = 1;
    for i = 1:N
        ro = (i-off)*L/N;
        f(i) = P*(L/N);
        w = P*L^4/(64*D)*(1-(ro/L)^2)^2;
        for j = 1:N
            r = (j-off)*L/N;
            if r > ro
                G3 = ro/(4*r)*(((ro/r)^2+1)*log(r/ro)+(ro/r)^2-1);  % p. 472
              else
                G3 = 0;
            end;
            L3 = ro/(4*L)*(((ro/L)^2+1)*log(L/ro)+(ro/L)^2-1); % p. 472
            L6 = ro/(4*L)*((ro/L)^2-1+2*log(L/ro))  ;          % p. 472
            a(i ,j) = (L*(L^2-r^2)*L6/2/D-(L^3*L3-r^3*G3)/D);
%                      L9 = ro/L*((1+nu)/2*log(L/ro)+(1-nu)/4*(1-(ro/L)^2));
            uo = L^3*(L6-2*L3)/2/D ; %  p. 502
            Mc = -L*(1+nu)*L6;  % p. 502
            a(i,j) = (uo+Mc*r^2/2/D/(1+nu)+r^3/D*G3)/(2*pi*ro); %  p. 501
            
        end;
        m(i,i) = 2*pi*ro*L/N*rho*h;
        
    end;
    FS = 20;
    setFigure('Circ Plate');
    u = a'*f;
    axes('position',[.2 .1 .6 .51],...
         'fontsize',FS);
    [rM,qM] = meshgrid(([1:N]-.5)/N,linspace(0,2*pi,120));
    z = NaN*ones(size(rM));
    ind = ([1:N]-.5)/N;
    for j = 1:length(ind)
        z(rM == ind(j))=u(j);
    end
    z(rM==0)=u(1);
    z(rM==1)=u(N);
    rL = [.5:N-.5]/N;
    V = interp1(rL, u,[0:N]/N,[],'extrap')
    contourf(rM.*cos(qM),rM.*sin(qM),z,V,'edgecolor','none');
    colormap('gray')
    grid on
    
    axis 'equal'
    
    yl = get(gca,'ylim');
    xlabel('$x/r_a$','fontsize',FS+2,'interpreter','latex');
    ylabel('$y/r_a$','fontsize',FS+2,'interpreter','latex');
    hold on;
    set(gca,'clim',[-.5*u(1),1.2*u(1)])
%     for i = 1:N
%         plot(rL(i)*[1 1], [0 yl(2)],'k--');
%     end;
    xl = get(gca,'xlim');
    axes('position',[.5 .62 .3 .25],...
         'yaxislocation','right',...
         'ydir','reverse',...
         'xaxislocation','top',...
         'fontsize',FS,...
         'box','on'); hold on;

    plot(rL,u/u(1),'ko-','markersize',6,...
         'markerfacecolor','k','linewidth',4);
    grid on;
    xlabel('Normalized radius $r/r_a$','interpreter','latex',...
           'fontsize',FS+2)
    ylabel('$u(r)/u_o$','fontsize',FS+2,'interpreter','latex');
    set(gca,'xlim',[0, xl(2)],'ylim',[-.25 1.25]);
       D = -.2;
    for i = 1:N
        arrow([rL(i),D+u(i)/u(1)],...
              [rL(i),.2*D+u(i)/u(1)],10);
%         plot(rL(i)*[1 1],[u(i)/u(1), 1.25],'--k')
    end;
    
return


%                     L9 = ro/L*((1+nu)/2*log(L/ro)+(1-nu)/4*(1-(ro/L)^2));
%                     uo = L^3/2/D*(L9/(1+nu)-2*L3);
%                     Mc = -L*L9;
%             a(i,j) = (uo+Mc*r^2/2/D/(1+nu)+r^3/D*G3)*2*pi*r; %  p. 501
%             (with substituted LTy)
%                 if i == 1            
%                     a(i,j)= 1/16/pi/D*((3+nu)/(1+nu)*(L^2-r^2)-2*r^2*log(L/r)); % p.505
%                 else
%             uo = L^3*(L6-2*L3)/2/D ; %  p. 502
%             Mc = -L*(1+nu)*L6;  % p. 502

