function circPlateMDFmodal(modN)
    if nargin < 1
       modN = 1;
       
    end
    showType = '1D';
   % Roark's formulas for stress and strain, 7th edition p.
    N = 40;                    % discretization level
    r_a = 200e-6;    h = 1e-6;  % geometry

    % mat. properties
    Y = 150e9;    nu = .3;    rho = 2330;    D = Y*h^3/12/(1-nu^2);
    a = zeros(N,N);  m = zeros(N,N);
    off = .5;
    for i = 1:N
        ro = (i-off)*r_a/N;
        m(i,i) = 2*pi*ro*r_a/N*rho*h;        
        for j = 1:N
            r = (j-off)*r_a/N;
            if r > ro
                G3 = ro/(4*r)*(((ro/r)^2+1)*log(r/ro)+(ro/r)^2-1);  % p. 472
              else
                G3 = 0;
            end;
            L3 = ro/(4*r_a)*(((ro/r_a)^2+1)*log(r_a/ro)+(ro/r_a)^2-1); % p. 472
            L6 = ro/(4*r_a)*((ro/r_a)^2-1+2*log(r_a/ro))  ;          % p. 472
            uo = r_a^3*(L6-2*L3)/2/D ; %  p. 502
            Mc = -r_a*(1+nu)*L6;  % p. 502
            a(i,j) = (uo+Mc*r^2/2/D/(1+nu)+r^3/D*G3); %  p. 501
            a(i,j) = a(i,j)/ro/2/pi;
        end;
    end;
    

    FS = 20;
    setFigure('Circ Plate');
    [v,w] = eig(a*m);
    [rM,qM] = meshgrid(([1:N]-.5)/N,linspace(0,2*pi,120));
    z = NaN*ones(size(rM));
    ind = ([1:N]-.5)/N;
    w = 1./sqrt(diag(w));
    [w,indW] = sort(w);
    v=v(:,indW);
    v(:,modN) = -v(:,modN)/max(abs(v(:,modN)));
%     freq1Theory = (1.015*pi/r_a)^2*sqrt(D/rho)/2/pi*1e-3
    freq1Theory = (1.017*pi/r_a)^2*sqrt(D/(h*rho))/2/pi*1e-3
    for j = 1:length(ind)
        z(rM == ind(j))=v(j,modN);
    end
    
    switch showType
        case '1D'
            switch modN
                case 1
                    tit = '1^{st} mode';
                case 2
                    tit = '2^{nd} mode';
                case 3
                    tit = '3^{rd} mode';
            end;
            plot(rG/r_a,v(:,modN),'ok-','linewidth',2,'markerfacecolor','k')
            set(gca,'fontsize',20,'position',[.2 .2 -0.4 .6],'ydir','reverse')
            grid on
            xlabel(' $r/r_a$','interpreter','latex')
            ylabel('$\leftarrow u/u_a$','interpreter','latex')
            title(tit)
        case '2D'
            a = surfl(rM.*cos(qM),rM.*sin(qM),z);
            set(a,'edgecolor','none');
            colormap('gray')
%             set(gca,'zdir','reverse','fontsize',24)
            set(gca,'fontsize',24)
%             xlabel('$x/L$','interpreter','latex');
%             ylabel('$y/L$','interpreter','latex');
%             zlabel('$u/u_o$','interpreter','latex');
            axis off
%             set(gca,'clim',[-1.5 1.5])
            set(gca,'zlim',[-1,1])
%             title({['mode = ' num2str(modN) ', \itf\rm_{' num2str(modN) '} = ',...
%                    num2str(w(modN)/2/pi*1e-3,'%.2f') ' kHz'];...
%                    ['\itf\rm_1(theory) = ' num2str(freq1Theory) ' kHz']});
            title(['\itf\rm_{' num2str(modN) '} = ',...
                   num2str(w(modN)/2/pi*1e-3,'%.2f') ' kHz']);

    end;


    
    