function circPlateMDFmodalRQ(modN)
    if nargin < 1
       modN = 1;
    end
   % Roark's formulas for stress and strain, 7th edition p.
    N = 20;                    % discretization level
    L = 200e-6;    h = 1e-6;  % geometry
    d = 2e-6;
    % mat. properties
    Y = 150e9;    nu = .3;    rho = 2330;    D = Y*h^3/12/(1-nu^2);
    v = 5;
    eps0 = 8.854e-12;
    a = zeros(N,N);  m = zeros(N,N);
    off = .5;
    f = zeros(N,1);
    f(3) = 1;
    P = 1/2*v^2*eps0/d^2;
    co = (4+nu)/2/(1+nu);
    c1 = (6+nu)/2/(3+nu);
    c2 = (6+nu)/(4+nu);
    bo = 3*(2+nu)/2/(1+nu);
    b1 = 3*(4+nu)/2/(3+nu);
    b2 = 2*(5+nu)/(4+nu);
    ro = L/2/N;
    for i = 1:N
        ro = (i-off)*L/N;rG(i) = ro;
        f(i) = P*(L/N);
        w(i) = P*L^4/(64*D)*(1-(ro/L)^2)^2;
        for j = 1:N
            r = (j-off)*L/N;
            if r > ro
                G3 = ro/(4*r)*(((ro/r)^2+1)*log(r/ro)+(ro/r)^2-1);  % p. 472
              else
                G3 = 0;
            end;
            L3 = ro/(4*L)*(((ro/L)^2+1)*log(L/ro)+(ro/L)^2-1); % p. 472
            L6 = ro/(4*L)*((ro/L)^2-1+2*log(L/ro))  ;          % p. 472
            a(i ,j) = (L*(L^2-r^2)*L6/2/D-(L^3*L3-r^3*G3)/D);
%                      L9 = ro/L*((1+nu)/2*log(L/ro)+(1-nu)/4*(1-(ro/L)^2));
            uo = L^3*(L6-2*L3)/2/D ; %  p. 502
            Mc = -L*(1+nu)*L6;  % p. 502
            a(i,j) = (uo+Mc*r^2/2/D/(1+nu)+r^3/D*G3); %  p. 501
            
        end;
        m(i,i) = 2*pi*ro*L/N*rho*h;
        
    end;
    FS = 20;
    setFigure('Circ Plate');
    [v,w] = eig(a'*m);
    [rM,qM] = meshgrid(([1:N]-.5)/N,linspace(0,2*pi,120));
    z = NaN*ones(size(rM));
    ind = ([1:N]-.5)/N;
    w = 1./sqrt(diag(w));
    [w,indW] = sort(w);
    v=v(:,indW);
    v(:,modN) = v(:,modN)/max(abs(v(:,modN)));
    for j = 1:length(ind)
        z(rM == ind(j))=v(j,modN);
    end
    
%     plot(rG/L,v(:,modN),'ok-','linewidth',2,'markerfacecolor','k')
%     set(gca,'fontsize',20,'position',[.2 .2 .6 .6],'ydir','reverse')
%     grid on
%     xlabel('$r/r_o$','interpreter','latex')
%     ylabel('$u/u_o$','interpreter','latex')
%     
    surf(rM.*cos(qM),rM.*sin(qM),z,'edgecolor','none');
    colormap('gray')
    set(gca,'zdir','reverse','fontsize',20)
    xlabel('$x/L$','interpreter','latex');
    ylabel('$y/L$','interpreter','latex');
    zlabel('$u/u_o$','interpreter','latex');
    set(gca,'clim',[-1.5 1.5])
     
    title(['mode = ' num2str(modN) ', \itf\rm_{' num2str(modN) '} = ',...
           num2str(w(modN)/2/pi*1e-6,'%.2f') ' MHz']);


    
    