function circPlateRQ( mode)
    if nargin < 1
        mode = 1;
    end;
    n  = 1;               % current mode
    N1 = 20;              % Number of elements in the r-direction
    N2 = 20;              % Number of elements in the theta-direction
    N  = N1*N2;		     % Total number of elements  compare to 1D (radial only model) !
    r_a= 200e-6;		     % Radius [m]
    h = 1e-6;		     % Height [m]
    nu = 0.3;	         % Poisson ratio
    Y = 150e9;		     % Young's modulus [N/m^2]
    rho = 2330;		     % Mass density [kg/m^3]
    D = Y*h^3/12/(1-nu^2);    % Plate modulus
    a = zeros(N,N);           % Initialize mass and stiffness matrices
    m = zeros(N,N);
    dq = 2*pi/N2; dr = r_a/N1;  % define the element size
    for i = 1:N%in arange(0,N):
         i1 = floor(i*1.0/N1)+.5;
         i2 = mod(i, N1); 
         ri = r_a*i1/N1; 
         qi = 2*pi*i2/N2;
         m(i,i) = ri*dq*dr*rho*h;      % mass matrix is diagonal as before
         for j = i:N
              j1 = floor(j*1/N1)+.5;
              j2 = mod(j, N1);
              rj = r_a*j1/N1;
              qj = 2*pi*j2/N2;
              r1 = sqrt(ri^2+rj^2-2*ri*rj*cos(qj-qi));
              rx = r_a^2/ri;
              r2 = sqrt(rx^2 + rj^2 -2*rx*rj*cos(qj-qi));
              if i == j
                  a(i,j) = 1/(16*pi*D)*(r_a^2-ri^2)^2/r_a^2;
              else
                  a(i,j) = 1/(16*pi*D)*(ri^2*r2^2/r_a^2-r1^2*(1+2*log(ri*r2/r_a/r1)));
                  a(j,i) = a(i,j);
              end
         end
    end;
    [v,w] = eig(a*m);                        
    freq_kHz = 1./sqrt(w)/2/pi/1e3;
    [r,phi] = meshgrid(linspace(0,1,N1),linspace(0,2*pi,N2));
    
    uF = -v(:,mode)/max(abs(v(:,mode)));
    u  = reshape(uF,N1,N2); % construct 3D displacements
    surf(r.*cos(phi),r.*sin(phi),u)
return;




