function A = doublyClampedBeamMDF

     g = setGeometry;
    mp = setMatProp;
     n = 10; % discretization level (mesh)
     b = 1e-6;
     meff = (33/140+1/70*b/g.L+3*g.L*1/4/(g.L-b)^2)*mp.rho*g.L*g.w*g.h;
     keff = mp.E*g.w*g.h^3/4/(g.L-b);
     wAp = sqrt(keff/meff)/2/pi;
     % compute mass matrix
     M = eye(n)*mp.rho*g.L*g.h*g.w/(n-1);
     % compute the flexibilit matrix A (A = inv(K))
     A = zeros(n,n);
     for j = 0:n-1
         for i = 0:n-1
             if i>= j 
                A(i+1,j+1) = g.L^3/(6*mp.E*g.Ix*(n-1)^3)*j^2*...
                        ((3*i-j)-...
                         (3*(n-1)-j)*(3*i^2*(n-1)-2*i^3)/(n-1)^3-...
                         3*(i^3-(n-1)*i^2)/(n-1)^2);
             else
                 A(i+1,j+1) = A(j+1,i+1);
             end;
         end;
     end;     
     % solution: Modal analysis
     [v,w] = eig(A*M);   
     visModal(diag(w), v,n);

return

function g = setGeometry

    g.L = 40e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  4e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam

return

function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.E = 150e9;  % GPa

return

function visModal(w, v,n)

    figure('units','normalized','position',[.2 .05 .4 .85]);
    vSign = [1,-1,1];
    for i = 1:3     
         subplot(3,1,i)
         set(gca,'fontsize',18,'ylim',[-1 1]*1.1); hold on;
         plot([0:n-1]/(n-1),vSign(i)*[v(:,end-i+1)/max(abs(v(:,end-i+1)))],...
             '-ko','linewidth',2,'markerfacecolor','k');
         grid on;
         ylabel(['\itf\rm_{' num2str(i) '} = ' ...
                 num2str(1e-6/sqrt(w(end-i+1))/2/pi,'%.1f') ' MHz']);
         if i == 1
             title(['Number of elements \itn\rm = ' num2str(n)])
         end
     end;
     xlabel('Normalized length \itx/L');
     
return