function [freq_kHz, v, n1, n2] = plateRQ

    [r_a, h] = setGeometry;
    [rho, D] = setMatProp(h);
   [n1,n2,n] = setMesh;
    a = zeros(n,n);           % Initialize flexibility and mass matrices
    m = zeros(n,n);
    dq = 2*pi/n2; dr = r_a/n1;  % define the element size
    for i = 1:n
         i1 = floor(i/n1)+.5;
         i2 = mod(i,n1);
         ri = r_a*i1/n1; 
         qi = 2*pi*i2/n2;
         m(i,i) = ri*dq*dr*rho*h;                  % mass matrix is diagonal as before
         for j = 1:n
              j1 = floor(j/n1)+.5;
              j2 = mod(j,n1);
              rj = r_a*j1/n1;
              qj = 2*pi*j2/n2;
              r1 = sqrt(ri^2+rj^2-2*ri*rj*cos(qj-qi));
              rx = r_a^2/ri;
              r2 = sqrt(rx^2 + rj^2 -2*rx*rj*cos(qj-qi));
              if i == j
                  a(i,j) = 1/(16*pi*D)*(r_a^2-ri^2)^2/r_a^2;
              else
                  a(i,j) = 1/(16*pi*D)*(ri^2*r2^2/r_a^2-r1^2*(1+2*log(ri*r2/r_a/r1)));
                  a(j,i) = a(i,j);
              end;
         end;
    end;
    [v,w2] = eig(inv(a),m);            
    freq_kHz = sqrt(diag(w2))/2/pi/1e3;       

return
function [r_a, h] = setGeometry
    r_a = 200e-6;		% Radius [m]
      h = 1e-6;		    % Height [m]
return
function [rho, D] = setMatProp(h)
   nu = 0.3;	           % Poisson ratio
    Y = 150e9;		       % Young's modulus [N/m^2]
  rho = 2330;		       % Mass density [kg/m^3]
    D = Y*h^3/12/(1-nu^2); % Plate modulus
return
function [n1,n2,n] = setMesh
    n1 = 40;     % Number of elements in the r-direction
    n2 = 40;     % Number of elements in the theta-direction
    n  = n1*n2;  % Total number of elements  compare to 1D (radial only model) 
return
