function simplyHeldBeamMDF

     g = setGeometry;
    mp = setMatProp;
     n = 40; % discretization level (mesh)
     M = eye(n)*mp.rho*g.L*g.h*g.w/(n);
     % compute the flexibilit matrix A (A = inv(K))
     A = NaN*ones(n,n);
     for i = 0:n-1
         if i < round(g.g/g.L*(n-1))
             c = getCoeff1( i/(n-1) );
         else
             c = getCoeff2( i/(n-1) );
         end;
         fR2m = (i/(n-1)*g.L-g.g)/(g.L-2*g.g); 
         for j = 0:(n-1)
             if i <= j                
                 if i<= round(g.g/g.L*(n-1))                  
                    if j < round(g.g/g.L*(n-1))
                        A(i+1,j+1) = (g.L/(n-1))^3/(6*mp.Y*g.Ix)...
                                 *j^2*(j-3*i)+c(3)+c(4)*(j/(n-1))*g.L;
%                         fprintf('i = %d, j = %d, A(i,j) = %f',i,j,A(i,j))
                    elseif round(g.g/g.L*(n-1))<= j && j <= round((g.L-g.g)/g.L*(n-1))
                        A(i+1,j+1) = -fR2m*(j/(n-1)*g.L)^2/(6*mp.Y*g.Ix)...
                                 *(3*(g.L-g.g)-j/(n-1)*g.L)+c(5)+c(6)*j/(n-1)*g.L;
                        fprintf('i = %d, j = %d, A(i,j) = %e\n',i,j,A(i+1,j+1))
                    elseif round((g.L-g.g)/g.L*(n-1))<= j 
                        A(i+1,j+1) = c(7)+c(8)*j/(n-1)*g.L;
                    end;
                 elseif round(g.g/g.L*(n-1))<= i && i <= round((g.L-g.g)/g.L*(n-1))
                     if j <= round((g.L-g.g)/g.L*(n-1))
                        A(i+1,j+1) = -fR2m*(j/(n-1)*g.L)^2/(6*mp.Y*g.Ix)...
                                 *(3*(g.L-g.g)-j/(n-1)*g.L)+c(5)+c(6)*j/(n-1)*g.L;
                     else
                         A(i+1,j+1) = c(7)+c(8)*j/(n-1)*g.L;
                     end;
                 else
                     A(i+1,j+1) = A(n-i, n-j);
                 end;
             else
                 A(i+1,j+1) = A(j+1,i+1);
             end;
         end;
     end;     
     % solution: Modal analysis
     [v,w] = eig(A*M);
     
    [ppt, aP, sh] = startPowerpnt;
                  drawLine([1:n]/n,...
                           v(:,end)',...
                          sh,aP,1,[-1 1],0);
                  drawLine([1:n]/n,...
                           zeros(1,n),...
                          sh,aP,1,[-1 1],0);
                      
%                        [f,p] = uiputfile('.ppt');
return

function g = setGeometry

    g.L = 40e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  4e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam
    g.g = 0.1*g.L;

return

function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.Y = 150e9;  % GPa

return

function c = getCoeff1(ipn)
      
       g = setGeometry;
      mp = setMatProp;
      xo = ipn*g.L;
    fR2m = (xo-g.g)/(g.L-2*g.g);      % fR2 = fR2m*f
     % the boundary condition equations
leftHside = [1 xo -1 -xo 0 0 0 0;...
             0 1 0 -1 0 0 0 0;...
             0 0 1 g.g -1 -g.g 0 0;...
             0 0 0 1 0 -1 0 0;...
             0 0 0 0 1 g.L-g.g -1 -g.L+g.g;...
             0 0 0 0 0 1 0 -1;...
             0 0 1 g.g 0 0 0 0;
             0 0 0 0 0  0 1 g.L-g.g];
rightHside = [-xo^3/(3*mp.Y*g.Ix);...
              -xo^2/(2*mp.Y*g.Ix); ...
              -g.g^2*((g.g-3*xo)+fR2m*(3*g.L-4*g.g))/(6*mp.Y*g.Ix);...
              -g.g*((g.g-2*xo)-fR2m*(3*g.g-2*g.L))/(2*mp.Y*g.Ix);...
               fR2m*(g.L-g.g)^3/(3*mp.Y*g.Ix);...
               fR2m*(g.L-g.g)^2/(2*mp.Y*g.Ix);...
               -g.g^2*(g.g-3*xo)/(6*mp.Y*g.Ix);...
               0];
     c = leftHside\rightHside;

return

function c = getCoeff2(ipn)

       g = setGeometry;
      mp = setMatProp;
      xo = ipn*g.L;
    fR1m = (g.L-g.g-xo)/(g.L-2*g.g);  % fR1 = fR1m*f
    fR2m = (xo-g.g)/(g.L-2*g.g);      % fR2 = fR2m*f
     % the boundary condition equations
leftHside = [1 g.g -1 -g.g 0 0 0 0;...
             0 1 0 -1 0 0 0 0;...
             0 0 1 xo -1 -xo 0 0;...
             0 0 0 1 0 -1 0 0;...
             0 0 0 0 1 g.L-g.g -1 -g.L+g.g;...
             0 0 0 0 0 1 0 -1;...
             1 g.g 0 0 0 0 0 0;
             0 0 0 0 0 0 1 g.L-g.g];
rightHside = [fR1m*g.g^3/(3*mp.Y*g.Ix);...
              fR1m*g.g^2/(2*mp.Y*g.Ix); ...
             -xo^2*(fR1m*(3*g.g-xo)-fR2m*(3*g.g-3*g.L+xo))/(6*mp.Y*g.Ix);...
             -xo*(fR1m*(2*g.g-xo)+fR2m*(2*g.L-xo-2*g.g))/(2*mp.Y*g.Ix);...
              fR2m*(g.L-g.g)^3/(3*mp.Y*g.Ix);...
              fR2m*(g.L-g.g)^2/(2*mp.Y*g.Ix);...
              0;...
              0];
     c = leftHside\rightHside;

return
      
function visModal(w, v,n)
  
    fh = findobj('name','MDF modes');
    if isempty(fh)
        figure('units','normalized','position',[.2 .05 .4 .85],'name','MDF modes');
    else
        figure(fh)
        clf;
    end;
    g = setGeometry;
    vSign = [1,-1,-1];
    for i = 1:3     
         subplot(3,1,i)
         set(gca,'fontsize',18,'ylim',[-1 1]*1.1); hold on;
         plot([0:n-1]/(n-1),vSign(i)*v(:,end-i+1)/max(abs(v(:,end-i+1))),...
             '-ko','linewidth',2,'markerfacecolor','k');
         hold on;
         plot(g.g/g.L*[1 1],[-1 1],'k--','linewidth',2);
         plot((g.L-g.g)/g.L*[1 1],[-1 1],'k--','linewidth',2);
         grid on;
         ylabel(['\itf\rm_{' num2str(i) '} = ' ...
                 num2str(1e-6/sqrt(w(end-i+1))/2/pi,'%.1f') ' MHz']);
         if i == 1
             title(['Number of elements \itn\rm = ' num2str(n)])
         end
     end;
     xlabel('Normalized length \itx/L');
     
return

function [ppt, aP, sh] = startPowerpnt

     ppt = actxserver('powerpoint.application');
           ppt.Visible = 1;
    pptP = ppt.Presentations;
      aP = pptP.Add;
  slides = aP.slides;
  
  % find your version of office
     ver = str2double(ppt.Version);
   
  % for 2003
  if ver == 11
      S1 = slides.Add(1,11);
  end
           
  % for 2007
  if ver == 12
      bs = aP.SlideMaster.CustomLayouts.Item(7);
      S1 = slides.AddSlide(1,bs);
      sh = S1.Shapes;
  end
  
return

function  drawLine(x,y,sh,aP, lw, yl, fill)

     xl = [min(x), max(x)];xl = [0 1];

      h = aP.PageSetup.SlideHeight;
      w = aP.PageSetup.SlideWidth;
     x  = (x-xl(1))/diff(xl)*w/6+300;
     y  = h-(y-yl(1))/diff(yl)*h/12-200;
     A = single([x',y']);
    p1 = sh.AddPolyline(A);
    p1.Line.Weight = lw;
    p1.Line.ForeColor.RGB = 0;
% A(:,1) = A(:,1)-10;
% A(:,2) = A(:,2)+10;
%     p2 = sh.AddPolyline(A);
    
%     p2.Fill.Visible = 'msoTrue';
%     p2.Fill.ForeColor.RGB = 15395562;
%     p1.Fill.Visible = 'msoTrue';
 if fill
    p1.Fill.ForeColor.RGB = 8421504;
 end
%     p1.Line.Visible = 'msoFalse';
% 
return