function bentCombDriveCUP

    [w, hSi, hSiO2, h, d,...
    Le, I_Si, I_SiO2, N] = defineGeometry();
    [E_Si, E_SiO2,...
     alphaSi, alphaSiO2] = matProps();
                   kappa = computeKappa();
                   oxClr = [1 1 1]*.9;   % define oxide color
                   siClr = [1 1 1]*.6;   % define Si color
                   outLs = '--k';
                      Lb = drawBackbone;
    for i = 1:N
        xo = Lb-w/2-(i-1)*2*(w+d);
        drawElectrode(xo,1);
        drawElectrode(xo,-1);
    end;
    set(gcf,'renderer','zbuffer')
    view(70,26)
    axis off
    axis equal
    addAnnotations()
    
    function addAnnotations()
        arrow([Le,w,.65*Le],[.58*Le,12*w,h],8,...
            'BaseAngle',60);
        text(Le,w,.63*Le,{'Each electrode'; 'bends along'; 'its length'},...
                      'horizontalalignment','right')
        arrow([Le,w,-Le/2],[Le*2,-Le/4,h],8,...
            'BaseAngle',60);
        text(Le,w,-.53*Le,{'Backbone bends';'along its axis'},...
                      'horizontalalignment','right',...
                      'verticalalignment','middle')       
    end
    function [w, hSi, hSiO2, h, ...
             d, Le, I_Si, I_SiO2, N] = defineGeometry()
         
           w = 2;            % width micrometers
       hSiO2 = 1;            % height of the oxide
         hSi = 3;            % height of Si
           h = hSiO2+hSi;    % total height
           d = 2;            % spacing
          Le = 30;           % electrode length
        I_Si = w*hSi^3/12;   % area moment of inertia of Si
      I_SiO2 = w*hSiO2^3/12; % area moment of inertia of SiO2
           N = 5;            % number of electrodes
       
    end
    function [E_Si, E_SiO2, alphaSi, alphaSiO2] = matProps()
              E_Si = 168e9;     % [Pa] Young modulus of Si
            E_SiO2 = 70e9;      % [Pa] Young modulus of SiO2
           alphaSi = 2.6e-6;    % [1/K] linear temp. coeff. of thermal expansion
         alphaSiO2 = .5e-6;     % [1/K]
    end
    function kappa = computeKappa()
            To = 1200;      % [oC] CVD temperature
            T1 = 27;       % [oC] operating temperature 
            DT = (T1-To);
         kappa = 6*(alphaSi-alphaSiO2)*DT...
                /(h/2+2*(E_Si*I_Si+E_SiO2*I_SiO2)/h/w*(1/(E_Si*hSi)+1/(E_SiO2*hSiO2)));
    end
    function Lb = drawBackbone()
        hold on;
        Lb = 2*N*(w+d);
        % Draw the top oxide surface of the backbone
        patch([linspace(0,Lb,200), linspace(Lb,0,200)],...
              [-ones(1,200),ones(1,200)]*w/2,...
              [1/2*kappa*linspace(0,Lb,200).^2,1/2*kappa*linspace(Lb,0,200).^2],...
              oxClr); hold on;
        % Draw the side oxide surfaces of the backbone
        patch([linspace(0,Lb,200), linspace(Lb,0,200)],...
              -ones(1,400),...
              [1/2*kappa*linspace(0,Lb,200).^2,...
              1/2*kappa*linspace(Lb,0,200).^2-hSiO2],...
              oxClr);
        patch([linspace(0,Lb,200), linspace(Lb,0,200)],...
              ones(1,400),...
              [1/2*kappa*linspace(0,Lb,200).^2,...
              1/2*kappa*linspace(Lb,0,200).^2-hSiO2],...
              oxClr);
        patch(Lb*ones(1,4),...
              [-1 1 1 -1]*w/2,...
              1/2*kappa*Lb^2+[0 0 -1 -1]*hSiO2,...
              oxClr);
        % Draw the side si surfaces of the backbone
        patch([linspace(0,Lb,200), linspace(Lb,0,200)],...
              -ones(1,400),...
              [1/2*kappa*linspace(0,Lb,200).^2-hSiO2,...
              1/2*kappa*linspace(Lb,0,200).^2-hSiO2-hSi],...
              siClr);
        patch([linspace(0,Lb,200), linspace(Lb,0,200)],...
              ones(1,400),...
              [1/2*kappa*linspace(0,Lb,200).^2-hSiO2,...
              1/2*kappa*linspace(Lb,0,200).^2-hSiO2-hSi],...
              siClr);
        patch(Lb*ones(1,4),...
              [-1 1 1 -1]*w/2,...
              1/2*kappa*Lb^2-hSiO2+[0 0 -1 -1]*hSi,...
              siClr);
       % reference outline
        plot3([0,Lb],[-1 -1]*w/2,[0,0],outLs,'linewidth',1)
        plot3([0,Lb],[-1 -1]*w/2,[1,1]*(-hSiO2),outLs,'linewidth',1)
        plot3([0,Lb],[-1 -1]*w/2,[1,1]*(-hSiO2-hSi),outLs,'linewidth',1)
        plot3([0,Lb],[1 1]*w/2,[0,0],outLs,'linewidth',1)
        plot3([Lb,Lb],[-1 1]*w/2,[0,0],outLs,'linewidth',1);
        plot3([Lb,Lb],[-1 1]*w/2,[1,1]*(-hSiO2),outLs,'linewidth',1);
        plot3([Lb,Lb],[-1 1]*w/2,[1,1]*(-hSiO2-hSi),outLs,'linewidth',1);
        plot3([Lb,Lb],[1 1]*w/2,[0 -1]*(hSiO2+hSi),outLs,'linewidth',1)
        plot3([Lb,Lb],[-1 -1]*w/2,[0 -1]*(hSiO2+hSi),outLs,'linewidth',1)
    end
    function drawElectrode(xo,yDir)
        % draw top oxide
        patch(xo + w/2*[ones(1,200), -ones(1,200)],...
              yDir*(w/2+[linspace(0,Le,200),linspace(Le,0,200)]),...
              1/2*kappa*xo^2+1/2*kappa*[linspace(0,Le,200).^2,...
                                linspace(Le,0,200).^2],...
              oxClr);
        % side oxides
        patch(xo + w/2*ones(1,400),...
              yDir*(w/2+[linspace(0,Le,200),linspace(Le,0,200)]),...
              1/2*kappa*xo^2+[1/2*kappa*linspace(0,Le,200).^2,...
                             1/2*kappa*linspace(Le,0,200).^2-hSiO2],...
              oxClr);
        patch(xo - w/2*ones(1,400),...
              yDir*(w/2+[linspace(0,Le,200),linspace(Le,0,200)]),...
              1/2*kappa*xo^2+[1/2*kappa*linspace(0,Le,200).^2,...
                             1/2*kappa*linspace(Le,0,200).^2-hSiO2],...
              oxClr);
        patch(xo+[-1 1 1 -1]*w/2,...
              yDir*(w/2+Le*ones(1,4)),...
              1/2*kappa*xo^2+1/2*kappa*Le^2 +[0 0 -1 -1]*hSiO2,...
              oxClr);
        % side Si
        patch(xo + w/2*ones(1,400),...
              yDir*(w/2+[linspace(0,Le,200),linspace(Le,0,200)]),...
              1/2*kappa*xo^2+[1/2*kappa*linspace(0,Le,200).^2-hSiO2,...
                             1/2*kappa*linspace(Le,0,200).^2-hSiO2-hSi],...
              siClr);
        patch(xo - w/2*ones(1,400),...
              yDir*(w/2+[linspace(0,Le,200),linspace(Le,0,200)]),...
              1/2*kappa*xo^2+[1/2*kappa*linspace(0,Le,200).^2-hSiO2,...
                             1/2*kappa*linspace(Le,0,200).^2-hSiO2-hSi],...
              siClr);
        patch(xo+[-1 1 1 -1]*w/2,...
              yDir*(w/2+Le*ones(1,4)),...
              1/2*kappa*xo^2+1/2*kappa*Le^2 -hSiO2+[0 0 -1 -1]*hSi,...
              siClr);
        % reference
        LW = .75;
        plot3((xo+w/2)*[1 1],yDir*(w/2+[0,Le]),[0 0],outLs,'linewidth',LW);
        plot3((xo-w/2)*[1 1],yDir*(w/2+[0,Le]),[0 0],outLs,'linewidth',LW);
        plot3((xo+w/2)*[1 1],yDir*(w/2+[0,Le]),[-1 -1]*hSiO2,outLs,'linewidth',LW);
        plot3((xo-w/2)*[1 1],yDir*(w/2+[0,Le]),[-1 -1]*hSiO2,outLs,'linewidth',LW);
        plot3((xo+w/2)*[1 1],yDir*(w/2+[0,Le]),[-1 -1]*(hSiO2+hSi),outLs,'linewidth',LW);
        plot3((xo-w/2)*[1 1],yDir*(w/2+[0,Le]),[-1 -1]*(hSiO2+hSi),outLs,'linewidth',LW);
        plot3(xo+[-1 1]*w/2,yDir*(w/2+[Le,Le]),[0 0],outLs,'linewidth',LW);
        plot3(xo+[-1 1]*w/2,yDir*(w/2+[Le,Le]),[-1 -1]*hSiO2,outLs,'linewidth',LW);
        plot3(xo+[-1 1]*w/2,yDir*(w/2+[Le,Le]),[-1 -1]*(hSiO2+hSi),outLs,'linewidth',LW);
        plot3((xo-w/2)*[1 1],yDir*(w/2+Le)*[1 1],[0 -1]*(hSiO2+hSi),outLs,'linewidth',LW);
        plot3((xo+w/2)*[1 1],yDir*(w/2+Le)*[1 1],[0 -1]*(hSiO2+hSi),outLs,'linewidth',LW);
    end


end
