function piezoPlacementDynamic

     g = setGeometry;
    mp = setMatProp;
     n = 100; % discretization level (mesh)
     % compute mass matrix
     M = eye(n)*mp.rho*g.L*g.h*g.w/n;
     % compute the flexibilit matrix A (A = inv(K))
     A = zeros(n,n);
     for j = 1:n
         for i = 1:n
             if i>= j 
                A(i,j) = g.L^3/(6*mp.E*g.Ix*n^3)*(3*i*j^2-j^3);
             else
                 A(i,j) = A(j,i);
             end;
         end;
     end; 
     Np = floor(g.Lpiezo/g.L*n);
     ks = 1:(n-Np-1);
     uo = zeros(size(ks));
     w2 = eig(inv(A),M);
     m = 3;
     for m = 1:3
         uo(m,:) = zeros(size(ks));
         for k =ks 
             f = zeros(n,1);
             f(k)      = -1;
             f(k+1)    =  1;
             f(k+Np)   =  1;
             f(k+Np+1) = -1;
             u = (-w2(m)*M+inv(A))^(-1)*f;
             uo(m,k) = abs(u(end));
         end;
         uo(m,:) = uo(m,:)/max(uo(m,:));
     end;
     hP = plot((ks+Np+1)/n,uo,'linewidth',2,'color','k');
     set(hP(1),'linestyle',':');
     set(hP(2),'linestyle','--');
     set(gca,'fontsize',16,'xlim',[0 1],'ylim',[0 1])
     xlabel({'Piezo element''s outer edge','(normalized by beam''s length)'})
     ylabel({'Beam tip displacement','(normalized wrt to optimum)'});
     legend('\itm\rm = 1','\itm\rm = 2','\itm\rm = 3','location','best');
     grid on     
   
return

function g = setGeometry

    g.L = 40e-6; % length in m
    g.h =  2e-6;  % height in m
    g.w =  4e-6;   % width in m
    g.Ix = g.h^3*g.w/12;  % prismatic beam
    g.Lpiezo = g.L/10;

return

function mp = setMatProp

    mp.rho = 2330; % kg/m^3
    mp.E = 150e9;  % GPa

return
