function piezoPlacement
       g = setGeometry;
    mp = setMatProp;
       n = 100;                                           % discretization level (mesh)
      m = eye(n)*mp.rho*g.L*g.h*g.w/n;   % compute mass matrix
% compute the flexibilit matrix a (a = inv(K))
      a = zeros(n,n);                                  % initiate the flexibility matrix
      fr = g.L^3/(6*mp.E*g.Ix*n^3);            % compute this product ones (needed for A)
     for j = 1:n
         for i = 1:n
             if i>= j 
                a(i,j) = fr*(3*i*j^2-j^3);            % update flexibility matrix
             else
                 a(i,j) = a(j,i);                          % reciprocity
             end;
         end;
     end; 
     Np = floor(g.Lpiezo/g.L*n);        % Number of DOF between piezo edges
     ks = 1:(n-Np-1);                         % possibility for the left edge of the piezo
     uo = zeros(3,length(ks));           % Initiate displacements
     w2 = eig(inv(a),m);                    % Compute squares of natural frequencies
     for k  = 1:3                                 % Select the mode of interest
         uo(k,:) = zeros(size(ks));
         for i =ks 
             f         = zeros(n,1);           % initiate force to zero
             f(i)      = -1;                        % doublet approximation
             f(i+1)    =  1;
             f(i+Np)   =  1;
             f(i+Np+1) = -1;
             u         = (-w2(k)*m+inv(a))^(-1)*f;   
             uo(k,i)   = abs(u(end));
         end;
         uo(k,:) = uo(k,:)/max(uo(k,:));
     end;
    % Plot the tip displacements as the function of the piezo placement
     hP = plot((ks+Np+1)/n,uo,'linewidth',2,'color','k')
     set(hP(1),'linestyle',':')
     set(hP(2),'linestyle','--')
     set(gca,'fontsize',16, 'xlim',[0 1],'ylim',[0 1])
     xlabel({'Piezo element''s outer edge','(normalized by beam''s length)'})
     ylabel({'Beam tip displacement','(normalized wrt to optimum)'});
     grid on  
     legend('\itk\rm = 1','\itk\rm = 2','\itk\rm = 3','location','best')
return
function g = setGeometry
    g.L = 40e-6;   % length in meters
    g.h =  2e-6;   % height in meters
    g.w =  4e-6;   % width in meters
    g.Ix = g.h^3*g.w/12;  % prismatic beam
    g.Lpiezo = g.L/5;
return
function mp = setMatProp 
    mp.rho = 2330; % kg/m^3
    mp.E = 150e9;  % GPa 
return
