function spinGyro

    % - Parameters
    FS   = 9;             % font size
    rRot = 8;
    hRot = 6;
    rBar = 1;
    hBar = 10;
    wAnn = 1;
    rIn  = hBar+hRot/2;
    rOut = rIn + wAnn;
    hAnn = 2*rBar;
    hBar2 = 2;
    % - start drawing
    setFigure('SpinGyro'); set(gcf,'renderer','opengl')

    drawCylinderX(rBar,hBar,-hRot/2-hBar/2,[1 1 1]*.5,[1 1 1]*0,10); 
    drawCylinderX(rRot,hRot,0,[1 1 1]*.5,[1 1 1]*.3, 100);  % the mass of the rotor
    drawCylinderX(rBar,hBar,hRot/2+hBar/2,[1 1 1]*.5,[1 1 1]*0,10); 
    drawCylinderY(rBar,hBar2,rOut+hBar2,[1 1 1]*.5,[1 1 1]*0,10); 
    drawCylinderY(rBar,hBar2,-rOut-hBar2,[1 1 1]*.5,[1 1 1]*0,10); 
    drawAnnulusX(rIn,rOut,hAnn,0, [1 1 1]*.5,[1 1 1]*.4,50)
    drawAnnulusZ(rIn+wAnn,rOut+wAnn,hAnn,0, [1 1 1]*.5,[1 1 1]*.4,50)
    drawAnnulusY(rOut+hBar2,rOut+hBar2+wAnn,hAnn,0, [1 1 1]*.5,[1 1 1]*.4,50)    
    plotFrills(rOut, rRot, hRot, FS)


return

function  drawCylinderX(r,h, zOff, fClr,eClr, N)

    q = linspace(0,2*pi,N);
    patch(h/2*ones(size(q))+zOff,r*cos(q),r*sin(q),fClr);   % top
    patch(-h/2*ones(size(q))+zOff,r*cos(q),r*sin(q),fClr);  % bottom
    hold on;
    % side
    for i = 1:length(q)-1
        patch([-1 -1 1 1]*h/2+zOff,...
              r*[cos(q(i)),cos(q(i+1)),cos(q(i+1)),cos(q(i))],...
              r*[sin(q(i)),sin(q(i+1)),sin(q(i+1)),sin(q(i))],...
              eClr,'edgecolor',eClr);   
    end;
    
return

function  drawCylinderZ(r,h, zOff, fClr,eClr, N)

    q = linspace(0,2*pi,N);
    patch(r*cos(q),r*sin(q),h/2*ones(size(q))+zOff,fClr);   % top
    patch(r*cos(q),r*sin(q),-h/2*ones(size(q))+zOff,fClr);  % bottom
    hold on;
    % side
    for i = 1:length(q)-1
        patch(r*[cos(q(i)),cos(q(i+1)),cos(q(i+1)),cos(q(i))],...
              r*[sin(q(i)),sin(q(i+1)),sin(q(i+1)),sin(q(i))],...
              [-1 -1 1 1]*h/2+zOff,eClr,'edgecolor',eClr);   
    end;
    
return

function  drawCylinderY(r,h, yOff, fClr,eClr, N)

    q = linspace(0,2*pi,N);
    patch(r*cos(q),h/2*ones(size(q))+yOff,r*sin(q),fClr);   % top
    patch(r*cos(q),-h/2*ones(size(q))+yOff,r*sin(q),fClr);  % bottom
    hold on;
    % side
    for i = 1:length(q)-1
        patch(r*[cos(q(i)),cos(q(i+1)),cos(q(i+1)),cos(q(i))],...
              [-1 -1 1 1]*h/2+yOff,...
              r*[sin(q(i)),sin(q(i+1)),sin(q(i+1)),sin(q(i))],...
              eClr,'edgecolor',eClr);   
    end;
    
return


function drawAnnulusZ(rIn, rOut, h, zOff, fClr,eClr, N)

    q = linspace(0,2*pi,N);
    patch([rIn*cos(q),rOut*cos(fliplr(q))],...
          [rIn*sin(q),rOut*sin(fliplr(q))],...
          h/2*ones(2*length(q))+zOff,fClr);   % top
    patch([rIn*cos(q),rOut*cos(fliplr(q))],...
          [rIn*sin(q),rOut*sin(fliplr(q))],...
          -h/2*ones(2*length(q))+zOff,fClr);   % bottom

    % sides
    for i = 1:length(q)-1
        patch(rOut*[cos(q(i)),cos(q(i+1)),cos(q(i+1)),cos(q(i))],...
              rOut*[sin(q(i)),sin(q(i+1)),sin(q(i+1)),sin(q(i))],...
              [-1 -1 1 1]*h/2+zOff,eClr,'edgecolor',eClr);   
        patch(rIn*[cos(q(i)),cos(q(i+1)),cos(q(i+1)),cos(q(i))],...
              rIn*[sin(q(i)),sin(q(i+1)),sin(q(i+1)),sin(q(i))],...
              [-1 -1 1 1]*h/2+zOff,eClr,'edgecolor',eClr);   
    end;
    
return

function drawAnnulusX(rIn, rOut, h, zOff, fClr,eClr, N)

    q = linspace(0,2*pi,N);
    patch([rIn*cos(q),rOut*cos(fliplr(q))],...
          h/2*ones(2*length(q))+zOff,[rIn*sin(q),...
          rOut*sin(fliplr(q))],fClr);   % top
    patch([rIn*cos(q),rOut*cos(fliplr(q))],...
          -h/2*ones(2*length(q))+zOff,[rIn*sin(q),...
          rOut*sin(fliplr(q))],fClr);   % top

    % sides
    for i = 1:length(q)-1
        patch(rOut*[cos(q(i)),cos(q(i+1)),cos(q(i+1)),cos(q(i))],...
              [-1 -1 1 1]*h/2+zOff,...
              rOut*[sin(q(i)),sin(q(i+1)),sin(q(i+1)),sin(q(i))],eClr,'edgecolor',eClr);   
        patch(rIn*[cos(q(i)),cos(q(i+1)),cos(q(i+1)),cos(q(i))],...
              [-1 -1 1 1]*h/2+zOff,...
              rIn*[sin(q(i)),sin(q(i+1)),sin(q(i+1)),sin(q(i))],eClr,'edgecolor',eClr);   
    end;
    
return

function drawAnnulusY(rIn, rOut, h, zOff, fClr,eClr, N)

    q = linspace(0,2*pi,N);
    patch(h/2*ones(2*length(q))+zOff,...
          [rIn*cos(q),rOut*cos(fliplr(q))],...
          [rIn*sin(q),rOut*sin(fliplr(q))],fClr);   % top
    patch(-h/2*ones(2*length(q))+zOff,...
          [rIn*cos(q),rOut*cos(fliplr(q))],...
          [rIn*sin(q),rOut*sin(fliplr(q))],fClr);   % top

    % sides
    for i = 1:length(q)-1
        patch([-1 -1 1 1]*h/2+zOff,...
              rOut*[cos(q(i)),cos(q(i+1)),cos(q(i+1)),cos(q(i))],...
              rOut*[sin(q(i)),sin(q(i+1)),sin(q(i+1)),sin(q(i))],eClr,'edgecolor',eClr);   
        patch([-1 -1 1 1]*h/2+zOff,...
              rIn*[cos(q(i)),cos(q(i+1)),cos(q(i+1)),cos(q(i))],...
              rIn*[sin(q(i)),sin(q(i+1)),sin(q(i+1)),sin(q(i))],eClr,'edgecolor',eClr);   
    end;
    
return

function plotFrills(rOut, rRot, hRot,FS)

    axis 'equal'
    axis 'off'
    view(114,23)
    % local axis
    arrow([-rOut-5 0 0],[rOut+5 0 0],10,'BaseAngle',60); 
    arrow([0 -rOut-5 0],[ 0 rOut+5 0],10,'BaseAngle',60);
    arrow([0 0 -rOut-5],[ 0 0 rOut+5],10,'BaseAngle',60);
    text(rOut+4,1,0,'\itx','fontsize',FS)
    text(0, rOut+5,1,'\ity','fontsize',FS)
    text(0, 1, rOut+4,'\itz','fontsize',FS)
    % global axis
    arrow([-rOut-5 -rOut-5 -rOut-5],[-rOut-5 -rOut-5 rOut+5],12,'BaseAngle',60); 
    arrow([-rOut-5 -rOut-5 -rOut-5],[-rOut-5 rOut+5 -rOut-5],12,'BaseAngle',60); 
    arrow([-rOut-5 -rOut-5 -rOut-5],[rOut+5 -rOut-5 -rOut-5],12,'BaseAngle',60); 
    text(rOut+4,-rOut-4,-rOut-4,'\itX_o','fontsize',FS)
    text(-rOut-4, rOut+4,-rOut-4,'\itY_o','fontsize',FS)
    text(-rOut-4, -rOut-4, rOut+4,'\itZ_o','fontsize',FS)
    
    arrow fixaxis
    text( rRot/2,rRot/2,hRot, '\Omega_{\itx}','fontsize',FS)
    q = linspace(0,pi/3,10);
    dR = rRot/20;
    patch((hRot/2+.5)*ones(2*length(q)+3,1),...
           [(rRot/2-dR)*cos(q),(rRot/2-2*dR)*cos(q(end)),...
           rRot/2*cos(pi/2), (rRot/2+2*dR)*cos(q(end)),(rRot/2+dR)*cos(fliplr(q))],...
           [(rRot/2-dR)*sin(q),(rRot/2-2*dR)*sin(q(end)),...
           rRot/2*sin(pi/2), (rRot/2+2*dR)*sin(q(end)),(rRot/2+dR)*sin(fliplr(q))],...
           [1 1 1]*0);

return
    